# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GRAD_FLIP_TEST_METADATA = Metadata(
    id="83d02b240a4d1a85f3fc3038b96542312f180177.boutiques",
    name="@GradFlipTest",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGradFlipTestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__grad_flip_test(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Text file that stores recommended flip option"""
    temp_directory: OutputPathType
    """Temporary working directory to store intermediate files"""


def v__grad_flip_test(
    dwi: InputPathType,
    grad_col_mat_t: InputPathType | None = None,
    grad_col_mat_t_: InputPathType | None = None,
    grad_col_mat_t_2: InputPathType | None = None,
    grad_col_mat_t_3: InputPathType | None = None,
    mask: InputPathType | None = None,
    bvals: InputPathType | None = None,
    thresh_fa: float | None = None,
    thresh_len: float | None = None,
    prefix: str | None = None,
    check_abs_min: float | None = None,
    scale_out_1000: bool = False,
    wdir: str | None = None,
    do_clean: bool = False,
    runner: Runner | None = None,
) -> VGradFlipTestOutputs:
    """
    Script to test the correct flip for a data set when using 1dDW_Grad_o_Mat++.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dwi: Set of DWIs (N total volumes).
        grad_col_mat_t: Set of column-wise g- or b-matrix elements\
            ("TORTOISE"-style format, "row-first").
        grad_col_mat_t_: Set of column-wise g- or b-matrix elements\
            ("TORTOISE"-style format, "row-first").
        grad_col_mat_t_2: Set of column-wise g- or b-matrix elements\
            ("TORTOISE"-style format, "row-first").
        grad_col_mat_t_3: Set of column-wise g- or b-matrix elements\
            ("TORTOISE"-style format, "row-first").
        mask: Optional mask (probably whole brain); otherwise, automasking is\
            performed.
        bvals: Can input bvals, if necessary (but shouldn't be necessary?).
        thresh_fa: Set minimum FA value for tracking (default X=0.2).
        thresh_len: Set minimum tract length to keep a tract when propagating\
            (default L=30mm).
        prefix: Output name of text file that stores recommended flip option.
        check_abs_min: Handle tiny negative values in gradient vectors.
        scale_out_1000: Scale output to 1000, as in 3dDWItoDT (probably not\
            necessary).
        wdir: Rename working directory output; useful if running multiple\
            iterations.
        do_clean: Remove temporary directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGradFlipTestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GRAD_FLIP_TEST_METADATA)
    cargs = []
    cargs.append("@GradFlipTest")
    cargs.extend([
        "-in_dwi",
        execution.input_file(dwi)
    ])
    if grad_col_mat_t is not None:
        cargs.extend([
            "-in_col_matT",
            execution.input_file(grad_col_mat_t)
        ])
    if grad_col_mat_t_ is not None:
        cargs.extend([
            "-in_col_matT",
            execution.input_file(grad_col_mat_t_)
        ])
    if grad_col_mat_t_2 is not None:
        cargs.extend([
            "-in_col_matT",
            execution.input_file(grad_col_mat_t_2)
        ])
    if grad_col_mat_t_3 is not None:
        cargs.extend([
            "-in_col_matT",
            execution.input_file(grad_col_mat_t_3)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if bvals is not None:
        cargs.extend([
            "-in_bvals",
            execution.input_file(bvals)
        ])
    if thresh_fa is not None:
        cargs.extend([
            "-alg_Thresh_FA",
            str(thresh_fa)
        ])
    if thresh_len is not None:
        cargs.extend([
            "-alg_Thresh_Len",
            str(thresh_len)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if check_abs_min is not None:
        cargs.extend([
            "-check_abs_min",
            str(check_abs_min)
        ])
    if scale_out_1000:
        cargs.append("-scale_out_1000")
    if wdir is not None:
        cargs.extend([
            "-wdir",
            wdir
        ])
    if do_clean:
        cargs.append("-do_clean")
    ret = VGradFlipTestOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".txt") if (prefix is not None) else None,
        temp_directory=execution.output_file("_tmp_TESTFLIP"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGradFlipTestOutputs",
    "V__GRAD_FLIP_TEST_METADATA",
    "v__grad_flip_test",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKEVOL_METADATA = Metadata(
    id="b095c7a5e6e89f542d67def46cd9241f840756fe.boutiques",
    name="makevol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakevolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `makevol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """The created volume file."""


def makevol(
    filename: str | None = "new_volume.mgz",
    width: int | None = 256,
    height: int | None = 256,
    depth: int | None = 256,
    sizex: float | None = 1.0,
    sizey: float | None = 1.0,
    sizez: float | None = 1.0,
    set_method: str | None = "xyz",
    runner: Runner | None = None,
) -> MakevolOutputs:
    """
    A tool to create a volume with given parameters.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filename: Write volume to the given file name, implying type.
        width: Use integer WIDTH as the x dimension.
        height: Use integer HEIGHT as the y dimension.
        depth: Use integer DEPTH as the z dimension.
        sizex: Use float SIZEX as the x resolution.
        sizey: Use float SIZEY as the y resolution.
        sizez: Use float SIZEZ as the z resolution.
        set_method: Use METHOD to fill the values. Methods: xyz, random,\
            constant.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakevolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKEVOL_METADATA)
    cargs = []
    cargs.append("makevol")
    if filename is not None:
        cargs.extend([
            "-f",
            filename
        ])
    if width is not None:
        cargs.extend([
            "-x",
            str(width)
        ])
    if height is not None:
        cargs.extend([
            "-y",
            str(height)
        ])
    if depth is not None:
        cargs.extend([
            "-z",
            str(depth)
        ])
    if sizex is not None:
        cargs.extend([
            "--sizex",
            str(sizex)
        ])
    if sizey is not None:
        cargs.extend([
            "--sizey",
            str(sizey)
        ])
    if sizez is not None:
        cargs.extend([
            "--sizez",
            str(sizez)
        ])
    if set_method is not None:
        cargs.extend([
            "--set-method",
            set_method
        ])
    ret = MakevolOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(filename) if (filename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKEVOL_METADATA",
    "MakevolOutputs",
    "makevol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_ICOSAHEDRON_METADATA = Metadata(
    id="0c5ed33e6d9371f02ee960933e1903bb9350e470.boutiques",
    name="CreateIcosahedron",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class CreateIcosahedronOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_icosahedron(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def create_icosahedron(
    rad: float | None = None,
    rec_depth: float | None = None,
    lin_depth: float | None = None,
    min_nodes: float | None = None,
    nums: bool = False,
    nums_quiet: bool = False,
    center_coordinates: list[float] | None = None,
    to_sphere: bool = False,
    output_prefix: str | None = None,
    help_: bool = False,
    runner: Runner | None = None,
) -> CreateIcosahedronOutputs:
    """
    Tool to create an icosahedron with optional tessellation.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        rad: Size of icosahedron.
        rec_depth: Recursive tessellation depth for icosahedron.
        lin_depth: Number of edge divides for linear icosahedron tessellation.
        min_nodes: Automatically select the -ld value which produces an\
            icosahedron of at least MIN_NODES nodes.
        nums: Output the number of nodes (vertices), triangles, edges, total\
            volume, and total area then quit.
        nums_quiet: Output numbers in a less verbose manner.
        center_coordinates: Coordinates of the center of the icosahedron.
        to_sphere: Project nodes to sphere.
        output_prefix: Prefix for output files.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateIcosahedronOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_ICOSAHEDRON_METADATA)
    cargs = []
    cargs.append("CreateIcosahedron")
    if rad is not None:
        cargs.extend([
            "-rad",
            str(rad)
        ])
    if rec_depth is not None:
        cargs.extend([
            "-rd",
            str(rec_depth)
        ])
    if lin_depth is not None:
        cargs.extend([
            "-ld",
            str(lin_depth)
        ])
    if min_nodes is not None:
        cargs.extend([
            "-min_nodes",
            str(min_nodes)
        ])
    if nums:
        cargs.append("-nums")
    if nums_quiet:
        cargs.append("-nums_quiet")
    if center_coordinates is not None:
        cargs.extend([
            "-ctr",
            *map(str, center_coordinates)
        ])
    if to_sphere:
        cargs.append("-tosphere")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if help_:
        cargs.append("-help")
    ret = CreateIcosahedronOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_ICOSAHEDRON_METADATA",
    "CreateIcosahedronOutputs",
    "create_icosahedron",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_GRAYPLOT_METADATA = Metadata(
    id="6d17ab08ae2c6bafb3bb5a4bc0dd707aa3956213.boutiques",
    name="3dGrayplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dGrayplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_grayplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    grayplot_img: OutputPathType | None
    """Grayplot image file"""


def v_3d_grayplot(
    input_: InputPathType,
    mask: InputPathType | None = None,
    prefix: str | None = None,
    dimensions: list[float] | None = None,
    resample_old: bool = False,
    polort: float | None = None,
    fwhm: float | None = None,
    pvorder: bool = False,
    ljorder: bool = False,
    peelorder: bool = False,
    ijkorder: bool = False,
    range_: float | None = None,
    percent: bool = False,
    raw_with_bounds: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dGrayplotOutputs:
    """
    Make a grayplot from a 3D+time dataset, like a carpet plot. Result is saved to a
    PNG image.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        mask: Name of mask dataset. Voxels that are 0 in the mask will not be\
            processed.
        prefix: Name for the output file. Default is Grayplot.png.
        dimensions: Output size of image in pixels: [width height]. Defaults\
            are width=1024 and height=512.
        resample_old: Original resampling method for processed dataset.
        polort: Order of polynomials for detrending. Default is 2. Use '-1' if\
            data is already detrended and de-meaned.
        fwhm: FWHM of blurring radius to use in the dataset before making the\
            image. Default is 0 mm.
        pvorder: Order the voxels by how well they match the two leading\
            principal components of their partition.
        ljorder: Order the voxels by their Ljung-Box statistics, a measure of\
            temporal correlation.
        peelorder: Order the voxels by how many 'peel' steps are needed to get\
            from the partition boundary to the voxel.
        ijkorder: Default intra-partition ordering by dataset 3D index ('ijk').
        range_: Set the range of the data to be plotted. Value of 0 is\
            middle-gray, +X is white, -X is black.
        percent: Scale values to percent differences from the mean of each\
            voxel timeseries. Suitable for raw time series datasets.
        raw_with_bounds: Map values <= A to black, values >= B to white, and\
            intermediate values to grays.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dGrayplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_GRAYPLOT_METADATA)
    cargs = []
    cargs.append("3dGrayplot")
    cargs.append(execution.input_file(input_))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if dimensions is not None:
        cargs.extend([
            "-dimen",
            *map(str, dimensions)
        ])
    if resample_old:
        cargs.append("-oldresam")
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if fwhm is not None:
        cargs.extend([
            "-fwhm",
            str(fwhm)
        ])
    if pvorder:
        cargs.append("-pvorder")
    if ljorder:
        cargs.append("-LJorder")
    if peelorder:
        cargs.append("-peelorder")
    if ijkorder:
        cargs.append("-ijkorder")
    if range_ is not None:
        cargs.extend([
            "-range",
            str(range_)
        ])
    if percent:
        cargs.append("-percent")
    if raw_with_bounds is not None:
        cargs.extend([
            "-raw_with_bounds",
            *map(str, raw_with_bounds)
        ])
    ret = V3dGrayplotOutputs(
        root=execution.output_file("."),
        grayplot_img=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dGrayplotOutputs",
    "V_3D_GRAYPLOT_METADATA",
    "v_3d_grayplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_WBC_METADATA = Metadata(
    id="92584218abde258bddf747b7925b1c16f3270082.boutiques",
    name="mri_wbc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriWbcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_wbc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_wbc(
    functional_volume: InputPathType,
    lh_functional_surface: InputPathType,
    lh_surface: InputPathType,
    rh_functional_surface: InputPathType,
    rh_surface: InputPathType,
    volume_mask: InputPathType | None = None,
    lh_inflated: InputPathType | None = None,
    lh_mask: InputPathType | None = None,
    lh_label: InputPathType | None = None,
    rh_inflated: InputPathType | None = None,
    rh_mask: InputPathType | None = None,
    rh_label: InputPathType | None = None,
    rho_threshold: float | None = None,
    dist_threshold: float | None = None,
    threads: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriWbcOutputs:
    """
    A tool for working with functional brain imaging data on surfaces and volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        functional_volume: Functional volume file.
        lh_functional_surface: Left hemisphere functional surface file.
        lh_surface: Left hemisphere surface file.
        rh_functional_surface: Right hemisphere functional surface file.
        rh_surface: Right hemisphere surface file.
        volume_mask: Mask for functional volume.
        lh_inflated: Optional left hemisphere inflated surface file.
        lh_mask: Mask for left hemisphere functional surface.
        lh_label: Label mask for left hemisphere functional surface.
        rh_inflated: Optional right hemisphere inflated surface file.
        rh_mask: Mask for right hemisphere functional surface.
        rh_label: Label mask for right hemisphere functional surface.
        rho_threshold: Rho threshold value.
        dist_threshold: Distance threshold value.
        threads: Number of threads to use.
        debug: Turn on debugging.
        checkopts: Check options and exit without running.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriWbcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_WBC_METADATA)
    cargs = []
    cargs.append("mri_wbc")
    cargs.extend([
        "--fvol",
        execution.input_file(functional_volume)
    ])
    if volume_mask is not None:
        cargs.extend([
            "--volmask",
            execution.input_file(volume_mask)
        ])
    cargs.extend([
        "--lh",
        execution.input_file(lh_functional_surface)
    ])
    cargs.extend([
        "--lh",
        execution.input_file(lh_surface)
    ])
    if lh_inflated is not None:
        cargs.extend([
            "--lh",
            execution.input_file(lh_inflated)
        ])
    if lh_mask is not None:
        cargs.extend([
            "--lhmask",
            execution.input_file(lh_mask)
        ])
    if lh_label is not None:
        cargs.extend([
            "--lhlabel",
            execution.input_file(lh_label)
        ])
    cargs.extend([
        "--rh",
        execution.input_file(rh_functional_surface)
    ])
    cargs.extend([
        "--rh",
        execution.input_file(rh_surface)
    ])
    if rh_inflated is not None:
        cargs.extend([
            "--rh",
            execution.input_file(rh_inflated)
        ])
    if rh_mask is not None:
        cargs.extend([
            "--rhmask",
            execution.input_file(rh_mask)
        ])
    if rh_label is not None:
        cargs.extend([
            "--rhlabel",
            execution.input_file(rh_label)
        ])
    if rho_threshold is not None:
        cargs.extend([
            "--rho",
            str(rho_threshold)
        ])
    if dist_threshold is not None:
        cargs.extend([
            "--dist",
            str(dist_threshold)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriWbcOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_WBC_METADATA",
    "MriWbcOutputs",
    "mri_wbc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SERIAL_HELPER_METADATA = Metadata(
    id="4df7ea7f38a6767c1aba72a89599b9e5c022108c.boutiques",
    name="serial_helper",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SerialHelperOutputs(typing.NamedTuple):
    """
    Output object returned when calling `serial_helper(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def serial_helper(
    serial_port: str,
    sock_num: float | None = None,
    mp_max: float | None = None,
    mp_min: float | None = None,
    num_extra: float | None = None,
    disp_all: float | None = None,
    debug: float | None = None,
    show_times: bool = False,
    help_: bool = False,
    hist: bool = False,
    no_serial: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> SerialHelperOutputs:
    """
    Passes motion parameters from socket to serial port.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        serial_port: Output serial port filename.
        sock_num: Specify socket number to serve.
        mp_max: Limit the maximum value of the MP data.
        mp_min: Limit the minimum value of the MP data.
        num_extra: Receive additional floats per TR.
        disp_all: Receive NVOX*8 extra floats per TR.
        debug: Set the debugging level (0-3).
        show_times: Show communication times.
        help_: Display this help information.
        hist: Show the module history.
        no_serial: Turn off serial port output.
        version: Show the current version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SerialHelperOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SERIAL_HELPER_METADATA)
    cargs = []
    cargs.append("serial_helper")
    cargs.extend([
        "-serial_port",
        serial_port
    ])
    if sock_num is not None:
        cargs.extend([
            "-sock_num",
            str(sock_num)
        ])
    if mp_max is not None:
        cargs.extend([
            "-mp_max",
            str(mp_max)
        ])
    if mp_min is not None:
        cargs.extend([
            "-mp_min",
            str(mp_min)
        ])
    if num_extra is not None:
        cargs.extend([
            "-num_extra",
            str(num_extra)
        ])
    if disp_all is not None:
        cargs.extend([
            "-disp_all",
            str(disp_all)
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if show_times:
        cargs.append("-show_times")
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if no_serial:
        cargs.append("-no_serial")
    if version:
        cargs.append("-version")
    ret = SerialHelperOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SERIAL_HELPER_METADATA",
    "SerialHelperOutputs",
    "serial_helper",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_EXPORT_DENSE_MAPPING_METADATA = Metadata(
    id="fb57b1ad6ea2cecd7c20af72044952f21f5e3510.boutiques",
    name="cifti-export-dense-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiExportDenseMappingVolumeAll:
    """
    export the the mapping of all voxels.
    """
    text_out: str
    """output - the output text file"""
    opt_no_cifti_index: bool = False
    """don't write the cifti index in the output file"""
    opt_structure: bool = False
    """write the structure each voxel belongs to in the output file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-all")
        cargs.append(self.text_out)
        if self.opt_no_cifti_index:
            cargs.append("-no-cifti-index")
        if self.opt_structure:
            cargs.append("-structure")
        return cargs


@dataclasses.dataclass
class CiftiExportDenseMappingSurface:
    """
    export the the mapping of one surface structure.
    """
    structure: str
    """the structure to output"""
    text_out: str
    """output - the output text file"""
    opt_no_cifti_index: bool = False
    """don't write the cifti index in the output file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface")
        cargs.append(self.structure)
        cargs.append(self.text_out)
        if self.opt_no_cifti_index:
            cargs.append("-no-cifti-index")
        return cargs


@dataclasses.dataclass
class CiftiExportDenseMappingVolume:
    """
    export the the mapping of one volume structure.
    """
    structure: str
    """the structure to output"""
    text_out: str
    """output - the output text file"""
    opt_no_cifti_index: bool = False
    """don't write the cifti index in the output file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume")
        cargs.append(self.structure)
        cargs.append(self.text_out)
        if self.opt_no_cifti_index:
            cargs.append("-no-cifti-index")
        return cargs


class CiftiExportDenseMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_export_dense_mapping(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_export_dense_mapping(
    cifti: InputPathType,
    direction: str,
    volume_all: CiftiExportDenseMappingVolumeAll | None = None,
    surface: list[CiftiExportDenseMappingSurface] | None = None,
    volume: list[CiftiExportDenseMappingVolume] | None = None,
    runner: Runner | None = None,
) -> CiftiExportDenseMappingOutputs:
    """
    Write index to element mapping as text.
    
    This command produces text files that describe the mapping from cifti
    indices to surface vertices or voxels. All indices are zero-based. The
    default format for -surface is lines of the form:
    
    <cifti-index> <vertex>
    
    The default format for -volume and -volume-all is lines of the form:
    
    <cifti-index> <i> <j> <k>
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti: the cifti file.
        direction: which direction to export the mapping from, ROW or COLUMN.
        volume_all: export the the mapping of all voxels.
        surface: export the the mapping of one surface structure.
        volume: export the the mapping of one volume structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiExportDenseMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_EXPORT_DENSE_MAPPING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-export-dense-mapping")
    cargs.append(execution.input_file(cifti))
    cargs.append(direction)
    if volume_all is not None:
        cargs.extend(volume_all.run(execution))
    if surface is not None:
        cargs.extend([a for c in [s.run(execution) for s in surface] for a in c])
    if volume is not None:
        cargs.extend([a for c in [s.run(execution) for s in volume] for a in c])
    ret = CiftiExportDenseMappingOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_EXPORT_DENSE_MAPPING_METADATA",
    "CiftiExportDenseMappingOutputs",
    "CiftiExportDenseMappingSurface",
    "CiftiExportDenseMappingVolume",
    "CiftiExportDenseMappingVolumeAll",
    "cifti_export_dense_mapping",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BET2_METADATA = Metadata(
    id="5366bd6b3b182667b9a0f23f9cf369e360294f91.boutiques",
    name="bet2",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Bet2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `bet2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType
    """Binary brain mask output (if mask flag is set)"""
    output_skull: OutputPathType
    """Approximate skull image output (if skull flag is set)"""
    output_mesh: OutputPathType
    """Brain surface mesh output in VTK format (if mesh flag is set)"""
    output_overlay: OutputPathType
    """Brain surface outline overlaid onto original image (if outline flag is
    set)"""


def bet2(
    input_fileroot: str,
    output_fileroot: str,
    fractional_intensity: float | None = None,
    vertical_gradient: float | None = None,
    center_of_gravity: list[float] | None = None,
    outline_flag: bool = False,
    mask_flag: bool = False,
    skull_flag: bool = False,
    no_output_flag: bool = False,
    mesh_flag: bool = False,
    head_radius: float | None = None,
    smooth_factor: float | None = None,
    threshold_flag: bool = False,
    verbose_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> Bet2Outputs:
    """
    Automated brain extraction tool for FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_fileroot: Input file root (e.g. img).
        output_fileroot: Output file root (e.g. img_bet).
        fractional_intensity: Fractional intensity threshold (0->1);\
            default=0.5; smaller values give larger brain outline estimates.
        vertical_gradient: Vertical gradient in fractional intensity threshold\
            (-1->1); default=0; positive values give larger brain outline at\
            bottom, smaller at top.
        center_of_gravity: The xyz coordinates of the center of gravity\
            (voxels, not mm) of initial mesh surface. Must have exactly three\
            numerical entries in the list (3-vector).
        outline_flag: Generate brain surface outline overlaid onto original\
            image.
        mask_flag: Generate binary brain mask.
        skull_flag: Generate approximate skull image.
        no_output_flag: Don't generate segmented brain image output.
        mesh_flag: Generate brain surface as mesh in vtk format.
        head_radius: Head radius (mm not voxels); initial surface sphere is set\
            to half of this.
        smooth_factor: Smoothness factor; default=1; values smaller than 1\
            produce more detailed brain surface, values larger than one produce\
            smoother, less detailed surface.
        threshold_flag: Apply thresholding to segmented brain image and mask.
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Bet2Outputs`).
    """
    if fractional_intensity is not None and not (0 <= fractional_intensity <= 1): 
        raise ValueError(f"'fractional_intensity' must be between 0 <= x <= 1 but was {fractional_intensity}")
    if vertical_gradient is not None and not (-1 <= vertical_gradient <= 1): 
        raise ValueError(f"'vertical_gradient' must be between -1 <= x <= 1 but was {vertical_gradient}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(BET2_METADATA)
    cargs = []
    cargs.append("bet2")
    cargs.append(input_fileroot)
    cargs.append(output_fileroot)
    if fractional_intensity is not None:
        cargs.extend([
            "-f",
            str(fractional_intensity)
        ])
    if vertical_gradient is not None:
        cargs.extend([
            "-g",
            str(vertical_gradient)
        ])
    if center_of_gravity is not None:
        cargs.extend([
            "-c",
            *map(str, center_of_gravity)
        ])
    if outline_flag:
        cargs.append("-o")
    if mask_flag:
        cargs.append("-m")
    if skull_flag:
        cargs.append("-s")
    if no_output_flag:
        cargs.append("-n")
    if mesh_flag:
        cargs.append("-e")
    if head_radius is not None:
        cargs.extend([
            "-r",
            str(head_radius)
        ])
    if smooth_factor is not None:
        cargs.extend([
            "-w",
            str(smooth_factor)
        ])
    if threshold_flag:
        cargs.append("-t")
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    ret = Bet2Outputs(
        root=execution.output_file("."),
        output_mask=execution.output_file(output_fileroot + "_mask.nii.gz"),
        output_skull=execution.output_file(output_fileroot + "_skull.nii.gz"),
        output_mesh=execution.output_file(output_fileroot + "_mesh.vtk"),
        output_overlay=execution.output_file(output_fileroot + "_overlay.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BET2_METADATA",
    "Bet2Outputs",
    "bet2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NORMALIZE_METADATA = Metadata(
    id="600d2e82bac484d0fa09b08fc06b759b58c55a5b.boutiques",
    name="mri_normalize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNormalizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_normalize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Normalized output volume"""
    controlpoints_output: OutputPathType
    """Output final control points as a volume, applicable only with -aseg"""


def mri_normalize(
    input_vol: InputPathType,
    output_vol: str,
    norm_iters: float | None = None,
    disable_1d: bool = False,
    nonmax_suppress: float | None = None,
    conform: bool = False,
    nonconform: bool = False,
    gentle: bool = False,
    control_points: InputPathType | None = None,
    fonly_control_points: InputPathType | None = None,
    lonly_labels: InputPathType | None = None,
    labels: InputPathType | None = None,
    write_volumes: str | None = None,
    intensity_above: float | None = None,
    intensity_below: float | None = None,
    intensity_gradient: float | None = None,
    prune: bool = False,
    no_gentle_cp: bool = False,
    mask_file: InputPathType | None = None,
    atlas_transform: str | None = None,
    noskull: bool = False,
    monkey: bool = False,
    nosnr: bool = False,
    sigma_smooth: float | None = None,
    aseg_file: InputPathType | None = None,
    debug_v: str | None = None,
    debug_d: str | None = None,
    renorm_vol: InputPathType | None = None,
    checknorm_vol: str | None = None,
    load_read_cp: str | None = None,
    cp_output_vol: InputPathType | None = None,
    surface_transform: str | None = None,
    seed_value: float | None = None,
    print_help: bool = False,
    runner: Runner | None = None,
) -> MriNormalizeOutputs:
    """
    Normalize the white-matter, optionally based on control points. The input volume
    is converted into a new volume where white matter image values all range around
    110.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input MRI volume file.
        output_vol: Output MRI volume file.
        norm_iters: Use n 3D normalization iterations (default=2).
        disable_1d: Disable 1D normalization.
        nonmax_suppress: Turn non-maximum suppression on (1) or off (0) when\
            using interior of surfaces.
        conform: Interpolate and embed volume to be 256^3.
        nonconform: Do not conform the volume.
        gentle: Perform kinder gentler normalization.
        control_points: Use control points file (usually control.dat).
        fonly_control_points: Use only control points file.
        lonly_labels: Use only control points in label file.
        labels: Use control points in label file.
        write_volumes: Write control point (c) and bias field (b) volumes.
        intensity_above: Use control point with intensity above target\
            (default=25.0).
        intensity_below: Use control point with intensity below target\
            (default=10.0).
        intensity_gradient: Use max intensity/mm gradient (default=1.000).
        prune: Turn pruning of control points on/off (default=off).
        no_gentle_cp: Do not use gentle normalization with control points file.
        mask_file: Mask file to use.
        atlas_transform: Use atlas to exclude control points from being in\
            non-brain regions.
        noskull: Do not consider skull regions.
        monkey: Turns off 1D, sets num_3d_iter=1.
        nosnr: Disable SNR normalization.
        sigma_smooth: Smooth bias field with given sigma.
        aseg_file: Aseg file for processing.
        debug_v: For debugging.
        debug_d: For debugging.
        renorm_vol: Load volume and use all points in it that are exactly 110\
            as control points.
        checknorm_vol: Load volume and remove all control points that aren't in\
            [min max].
        load_read_cp: For reading control points and bias field.
        cp_output_vol: Output final control points as a volume (only with\
            -aseg).
        surface_transform: Normalize based on the skeleton of the interior of\
            the transformed surface.
        seed_value: Set random number generator to seed N.
        print_help: Print usage.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNormalizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NORMALIZE_METADATA)
    cargs = []
    cargs.append("mri_normalize")
    cargs.append(execution.input_file(input_vol))
    cargs.append(output_vol)
    if norm_iters is not None:
        cargs.extend([
            "-n",
            str(norm_iters)
        ])
    if disable_1d:
        cargs.append("-no1d")
    if nonmax_suppress is not None:
        cargs.extend([
            "-nonmax_suppress",
            str(nonmax_suppress)
        ])
    if conform:
        cargs.append("-conform")
    if nonconform:
        cargs.append("-noconform")
    if gentle:
        cargs.append("-gentle")
    if control_points is not None:
        cargs.extend([
            "-f",
            execution.input_file(control_points)
        ])
    if fonly_control_points is not None:
        cargs.extend([
            "-fonly",
            execution.input_file(fonly_control_points)
        ])
    if lonly_labels is not None:
        cargs.extend([
            "-lonly",
            execution.input_file(lonly_labels)
        ])
    if labels is not None:
        cargs.extend([
            "-label",
            execution.input_file(labels)
        ])
    if write_volumes is not None:
        cargs.extend([
            "-w",
            write_volumes
        ])
    if intensity_above is not None:
        cargs.extend([
            "-a",
            str(intensity_above)
        ])
    if intensity_below is not None:
        cargs.extend([
            "-b",
            str(intensity_below)
        ])
    if intensity_gradient is not None:
        cargs.extend([
            "-g",
            str(intensity_gradient)
        ])
    if prune:
        cargs.append("-prune")
    if no_gentle_cp:
        cargs.append("-no-gentle-cp")
    if mask_file is not None:
        cargs.extend([
            "-MASK",
            execution.input_file(mask_file)
        ])
    if atlas_transform is not None:
        cargs.extend([
            "-atlas",
            atlas_transform
        ])
    if noskull:
        cargs.append("-noskull")
    if monkey:
        cargs.append("-monkey")
    if nosnr:
        cargs.append("-nosnr")
    if sigma_smooth is not None:
        cargs.extend([
            "-sigma",
            str(sigma_smooth)
        ])
    if aseg_file is not None:
        cargs.extend([
            "-aseg",
            execution.input_file(aseg_file)
        ])
    if debug_v is not None:
        cargs.extend([
            "-v",
            debug_v
        ])
    if debug_d is not None:
        cargs.extend([
            "-d",
            debug_d
        ])
    if renorm_vol is not None:
        cargs.extend([
            "-renorm",
            execution.input_file(renorm_vol)
        ])
    if checknorm_vol is not None:
        cargs.extend([
            "-checknorm",
            checknorm_vol
        ])
    if load_read_cp is not None:
        cargs.extend([
            "-r",
            load_read_cp
        ])
    if cp_output_vol is not None:
        cargs.extend([
            "-c",
            execution.input_file(cp_output_vol)
        ])
    if surface_transform is not None:
        cargs.extend([
            "-surface",
            surface_transform
        ])
    if seed_value is not None:
        cargs.extend([
            "-seed",
            str(seed_value)
        ])
    if print_help:
        cargs.append("-u")
    ret = MriNormalizeOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(output_vol),
        controlpoints_output=execution.output_file("controlpoints_volume.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NORMALIZE_METADATA",
    "MriNormalizeOutputs",
    "mri_normalize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNPACK_MNC_TCL_METADATA = Metadata(
    id="54eec142d994829a43977ef77cc7f837f8d06635.boutiques",
    name="unpack_mnc.tcl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class UnpackMncTclOutputs(typing.NamedTuple):
    """
    Output object returned when calling `unpack_mnc_tcl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unpacked_file: OutputPathType | None
    """Unpacked output MINC file"""


def unpack_mnc_tcl(
    verbose: bool = False,
    output_dir: str | None = None,
    input_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> UnpackMncTclOutputs:
    """
    A tool for unpacking MINC format images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        verbose: Verbose output messages.
        output_dir: Output directory for unpacked files.
        input_file: Specify a custom input file for unpacking.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UnpackMncTclOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNPACK_MNC_TCL_METADATA)
    cargs = []
    cargs.append("unpack_mnc.tcl")
    if verbose:
        cargs.append("-v")
    if output_dir is not None:
        cargs.extend([
            "-o",
            output_dir
        ])
    if input_file is not None:
        cargs.extend([
            "-i",
            execution.input_file(input_file)
        ])
    ret = UnpackMncTclOutputs(
        root=execution.output_file("."),
        unpacked_file=execution.output_file(output_dir + "/unpacked_data.mnc") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNPACK_MNC_TCL_METADATA",
    "UnpackMncTclOutputs",
    "unpack_mnc_tcl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BREC_METADATA = Metadata(
    id="926878e94d713380f9f820e8daf052c7f36030e8.boutiques",
    name="brec",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class BrecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `brec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def brec(
    my_file: str,
    depth_limit: bool = False,
    runner: Runner | None = None,
) -> BrecOutputs:
    """
    A description for brec tool could not be retrieved.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        my_file: Input file with .rec extension.
        depth_limit: Optional depth limit flag.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BrecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BREC_METADATA)
    cargs = []
    cargs.append("brec")
    cargs.append(my_file)
    if depth_limit:
        cargs.append("-depth_limit")
    ret = BrecOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BREC_METADATA",
    "BrecOutputs",
    "brec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABELS_UNION_METADATA = Metadata(
    id="d5aa9c97375874b3bcbc62e4722154356911d0ad.boutiques",
    name="labels_union",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LabelsUnionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `labels_union(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    union_label: OutputPathType
    """Union of the two label files"""


def labels_union(
    label1: InputPathType,
    label2: InputPathType,
    outputname: str,
    runner: Runner | None = None,
) -> LabelsUnionOutputs:
    """
    Utility to create the union of two label files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label1: First label file (e.g., rh.BA3a.label).
        label2: Second label file (e.g., rh.BA3b.label).
        outputname: Output name for the union label file (e.g.,\
            rh.BA3ab.union.label).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelsUnionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABELS_UNION_METADATA)
    cargs = []
    cargs.append("labels_union")
    cargs.append(execution.input_file(label1))
    cargs.append(execution.input_file(label2))
    cargs.append(outputname)
    ret = LabelsUnionOutputs(
        root=execution.output_file("."),
        union_label=execution.output_file(outputname),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABELS_UNION_METADATA",
    "LabelsUnionOutputs",
    "labels_union",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REMOVE_NEGATIVE_VERTICES_METADATA = Metadata(
    id="c1064a10c7344f9e696303964c7ecc7e48d65433.boutiques",
    name="mris_remove_negative_vertices",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRemoveNegativeVerticesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_remove_negative_vertices(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_patch_file: OutputPathType
    """The resulting output patch file"""


def mris_remove_negative_vertices(
    surface_file: InputPathType,
    patch_file: InputPathType,
    output_patch: str,
    runner: Runner | None = None,
) -> MrisRemoveNegativeVerticesOutputs:
    """
    This program adds a template into an average surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface_file: Input surface file.
        patch_file: Patch file name.
        output_patch: Output patch file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRemoveNegativeVerticesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REMOVE_NEGATIVE_VERTICES_METADATA)
    cargs = []
    cargs.append("mris_remove_negative_vertices")
    cargs.append(execution.input_file(surface_file))
    cargs.append(execution.input_file(patch_file))
    cargs.append(output_patch)
    ret = MrisRemoveNegativeVerticesOutputs(
        root=execution.output_file("."),
        output_patch_file=execution.output_file(output_patch),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REMOVE_NEGATIVE_VERTICES_METADATA",
    "MrisRemoveNegativeVerticesOutputs",
    "mris_remove_negative_vertices",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXTRACTTXT_METADATA = Metadata(
    id="48cff102ad59e3a8afc267b63f335c1516c29429.boutiques",
    name="extracttxt",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class ExtracttxtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `extracttxt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Extracted text output file"""


def extracttxt(
    search_word: str,
    file: InputPathType,
    num_trailing_lines: float | None = 0,
    relative_start: float | None = 0,
    runner: Runner | None = None,
) -> ExtracttxtOutputs:
    """
    Extracts text from a file based on a search word.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        search_word: The word to search for in the file.
        file: Path to the file where text is to be extracted.
        num_trailing_lines: Number of trailing lines to include after the\
            search word.
        relative_start: Relative start position to begin the search.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExtracttxtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXTRACTTXT_METADATA)
    cargs = []
    cargs.append("extracttxt")
    cargs.append(search_word)
    cargs.append(execution.input_file(file))
    if num_trailing_lines is not None:
        cargs.append(str(num_trailing_lines))
    if relative_start is not None:
        cargs.append(str(relative_start))
    ret = ExtracttxtOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXTRACTTXT_METADATA",
    "ExtracttxtOutputs",
    "extracttxt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_FLATTEN_METADATA = Metadata(
    id="c7d351c53d00767efc2edd450d96b67b497b34f9.boutiques",
    name="mris_flatten",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisFlattenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_flatten(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_patch_file: OutputPathType
    """Output flattened surface patch"""


def mris_flatten(
    input_patch: InputPathType,
    output_patch: str,
    iterations: float | None = None,
    distances: list[float] | None = None,
    dilations: float | None = None,
    random_seed: float | None = None,
    copy_coords: str | None = None,
    norand: bool = False,
    runner: Runner | None = None,
) -> MrisFlattenOutputs:
    """
    This program will flatten a surface patch.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_patch: Input surface patch.
        output_patch: Output flattened surface patch.
        iterations: Write out the surface every # of iterations.
        distances: Specify size of neighborhood and number of vertices at each\
            distance to be used in the optimization.
        dilations: Specify the number of times to dilate the ripped edges to\
            ensure a clean cut.
        random_seed: Set the random seed to a specific value so that flattening\
            is repeatable.
        copy_coords: Copy xyz coords from surface before flattening.
        norand: Set the random seed to 0 so that flattening is repeatable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisFlattenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_FLATTEN_METADATA)
    cargs = []
    cargs.append("mris_flatten")
    cargs.append(execution.input_file(input_patch))
    cargs.append(output_patch)
    if iterations is not None:
        cargs.extend([
            "-w",
            str(iterations)
        ])
    if distances is not None:
        cargs.extend([
            "-distances",
            *map(str, distances)
        ])
    if dilations is not None:
        cargs.extend([
            "-dilate",
            str(dilations)
        ])
    if random_seed is not None:
        cargs.extend([
            "-seed",
            str(random_seed)
        ])
    if copy_coords is not None:
        cargs.extend([
            "-copy-coords",
            copy_coords
        ])
    if norand:
        cargs.append("-norand")
    ret = MrisFlattenOutputs(
        root=execution.output_file("."),
        output_patch_file=execution.output_file(output_patch),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_FLATTEN_METADATA",
    "MrisFlattenOutputs",
    "mris_flatten",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_24SWAP_METADATA = Metadata(
    id="bf5fd18b81c5c9e1a6698d3e136d7e97296fa6fb.boutiques",
    name="24swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V24swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_24swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_24swap(
    input_files: list[InputPathType],
    quiet: bool = False,
    pattern: str | None = None,
    runner: Runner | None = None,
) -> V24swapOutputs:
    """
    Swaps bytes pairs and/or quadruples on the files listed.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input file(s) to swap bytes.
        quiet: Operate quietly.
        pattern: Pattern that determines the pattern of 2 and 4 byte swaps.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V24swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_24SWAP_METADATA)
    cargs = []
    cargs.append("24swap")
    if quiet:
        cargs.append("-q")
    if pattern is not None:
        cargs.extend([
            "-pattern",
            pattern
        ])
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = V24swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V24swapOutputs",
    "V_24SWAP_METADATA",
    "v_24swap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_MRIS_PREPROC_METADATA = Metadata(
    id="3629333e45a8eb1987148cec6b9546163e9cda0d.boutiques",
    name="run_mris_preproc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RunMrisPreprocOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_mris_preproc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def run_mris_preproc(
    qdec_table: InputPathType,
    target_average: str | None = None,
    runner: Runner | None = None,
) -> RunMrisPreprocOutputs:
    """
    Utility to create pre-smoothed surface data on a target average subject for Qdec
    application.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec_table: Text file of subject data used by qdec.
        target_average: Specify a target average, default is fsaverage.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunMrisPreprocOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_MRIS_PREPROC_METADATA)
    cargs = []
    cargs.append("run_mris_preproc")
    cargs.append(execution.input_file(qdec_table))
    if target_average is not None:
        cargs.append(target_average)
    ret = RunMrisPreprocOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_MRIS_PREPROC_METADATA",
    "RunMrisPreprocOutputs",
    "run_mris_preproc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLMODHD_METADATA = Metadata(
    id="4d79af63e716050570a42ab303ea6efb6b7d6d71.boutiques",
    name="fslmodhd",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslmodhdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslmodhd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslmodhd(
    image: InputPathType,
    keyword_: str,
    value: str,
    runner: Runner | None = None,
) -> FslmodhdOutputs:
    """
    A tool for modifying header information of NIfTI images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        image: Input image file (e.g. image.nii.gz).
        keyword_: Header keyword to modify (e.g. 'dim', 'pixdim').
        value: New value for the given header keyword.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslmodhdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLMODHD_METADATA)
    cargs = []
    cargs.append("fslmodhd")
    cargs.append(execution.input_file(image))
    cargs.append(keyword_)
    cargs.append(value)
    ret = FslmodhdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLMODHD_METADATA",
    "FslmodhdOutputs",
    "fslmodhd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_DIFF_METADATA = Metadata(
    id="30172af00f20644762a6e2ce032311fb482cfc14.boutiques",
    name="mris_diff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_diff(
    surface1: InputPathType,
    surface2: InputPathType,
    subject1: str,
    subject2: str,
    hemisphere: str,
    subj_dir1: str | None = None,
    subj_dir2: str | None = None,
    runner: Runner | None = None,
) -> MrisDiffOutputs:
    """
    A tool for comparing differences between surface files in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface1: First surface file.
        surface2: Second surface file.
        subject1: Subject 1 name.
        subject2: Subject 2 name.
        hemisphere: Hemisphere (rh or lh).
        subj_dir1: Directory for Subject 1 (default is SUBJECTS_DIR).
        subj_dir2: Directory for Subject 2 (default is SUBJECTS_DIR).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_DIFF_METADATA)
    cargs = []
    cargs.append("mris_diff")
    cargs.append(execution.input_file(surface1))
    cargs.append(execution.input_file(surface2))
    cargs.extend([
        "--s1",
        subject1
    ])
    cargs.extend([
        "--s2",
        subject2
    ])
    if subj_dir1 is not None:
        cargs.extend([
            "--sd1",
            subj_dir1
        ])
    if subj_dir2 is not None:
        cargs.extend([
            "--sd2",
            subj_dir2
        ])
    cargs.extend([
        "--hemi",
        hemisphere
    ])
    ret = MrisDiffOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_DIFF_METADATA",
    "MrisDiffOutputs",
    "mris_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIX_SUBJECT_CORRECTED_METADATA = Metadata(
    id="e9683c6b2300288726f90faacf8034788b095c6c.boutiques",
    name="fix_subject_corrected",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FixSubjectCorrectedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fix_subject_corrected(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fix_subject_corrected(
    subject_directory: str,
    output_directory: str,
    runner: Runner | None = None,
) -> FixSubjectCorrectedOutputs:
    """
    Corrects subject data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_directory: Path to the subject's directory.
        output_directory: Path to the output directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixSubjectCorrectedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIX_SUBJECT_CORRECTED_METADATA)
    cargs = []
    cargs.append("fix_subject_corrected")
    cargs.append(subject_directory)
    cargs.append(output_directory)
    ret = FixSubjectCorrectedOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIX_SUBJECT_CORRECTED_METADATA",
    "FixSubjectCorrectedOutputs",
    "fix_subject_corrected",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_CENTRAL_SULCUS_METADATA = Metadata(
    id="13b958f09713b9767ab00695cb856a93c2ef9725.boutiques",
    name="map_central_sulcus",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MapCentralSulcusOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_central_sulcus(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    log_file: OutputPathType
    """Log file from recon-all process."""
    status_log_file: OutputPathType
    """Status log file from recon-all process."""


def map_central_sulcus(
    subjid: str,
    process_directive: str,
    hemi_flag: str | None = None,
    expert_prefs_file: InputPathType | None = None,
    xopts_use: bool = False,
    xopts_clean: bool = False,
    xopts_overwrite: bool = False,
    watershed_cmd: str | None = None,
    xmask_file: InputPathType | None = None,
    wsless: bool = False,
    wsmore: bool = False,
    wsatlas: bool = False,
    no_wsatlas: bool = False,
    no_wsgcaatlas: bool = False,
    wsthresh: float | None = None,
    wsseed: str | None = None,
    norm3diters: float | None = None,
    normmaxgrad: float | None = None,
    norm1_b: float | None = None,
    norm2_b: float | None = None,
    norm1_n: float | None = None,
    norm2_n: float | None = None,
    cm_flag: bool = False,
    no_fix_with_ga: bool = False,
    fix_diag_only: bool = False,
    seg_wlo: float | None = None,
    seg_ghi: float | None = None,
    nothicken: bool = False,
    no_ca_align_after: bool = False,
    no_ca_align: bool = False,
    deface: bool = False,
    mprage: bool = False,
    washu_mprage: bool = False,
    schwartzya3t_atlas: bool = False,
    mail_username: str | None = None,
    threads: float | None = None,
    runner: Runner | None = None,
) -> MapCentralSulcusOutputs:
    """
    Performs all, or any part of, the FreeSurfer cortical reconstruction process.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: FreeSurfer subject identification string which doubles as the\
            name of the reconstruction root directory for the subject.
        process_directive: Process directive for recon-all (e.g. -all,\
            -autorecon-all, -autorecon1).
        hemi_flag: Specify hemisphere processing (e.g., lh for left hemisphere\
            or rh for right hemisphere).
        expert_prefs_file: Read-in expert options file for processing.\
            Overrides default options.
        xopts_use: Use pre-existing expert options file.
        xopts_clean: Delete pre-existing expert options file.
        xopts_overwrite: Overwrite pre-existing expert options file.
        watershed_cmd: Controls how the skull stripping will be performed.
        xmask_file: Custom external brain mask to replace automated\
            skullstripping.
        wsless: Decrease watershed threshold (leaves less skull, but can strip\
            more brain).
        wsmore: Increase watershed threshold (leaves more skull, but can strip\
            less brain).
        wsatlas: Use atlas when skull stripping.
        no_wsatlas: Do not use atlas when skull stripping.
        no_wsgcaatlas: Do not use GCA atlas when skull stripping.
        wsthresh: Explicitly set watershed threshold.
        wsseed: Specify an index (C, R, S) point in the skull.
        norm3diters: Number of 3d iterations for mri_normalize.
        normmaxgrad: Max grad (-g) for mri_normalize. Default is 1.
        norm1_b: In the first usage of mri_normalize, use control point with\
            intensity N below target (default=10.0).
        norm2_b: In the second usage of mri_normalize, use control point with\
            intensity N below target (default=10.0).
        norm1_n: In the first usage of mri_normalize, do N number of\
            iterations.
        norm2_n: In the second usage of mri_normalize, do N number of\
            iterations.
        cm_flag: Conform volumes to the min voxel size.
        no_fix_with_ga: Do not use genetic algorithm when fixing topology.
        fix_diag_only: Topology fixer runs until ?h.defect_labels files are\
            created, then stops.
        seg_wlo: Set wlo value for mri_segment and mris_make_surfaces.
        seg_ghi: Set ghi value for mri_segment and mris_make_surfaces.
        nothicken: Pass '-thicken 0' to mri_segment.
        no_ca_align_after: Turn off -align-after with mri_ca_register.
        no_ca_align: Turn off -align with mri_ca_label.
        deface: Deface subject, written to orig_defaced.mgz.
        mprage: Assume scan parameters are MGH MP-RAGE protocol.
        washu_mprage: Assume scan parameters are Wash.U. MP-RAGE protocol.
        schwartzya3t_atlas: For tal reg, use special young adult 3T atlas.
        mail_username: Mail user when done.
        threads: Set number of threads to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapCentralSulcusOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_CENTRAL_SULCUS_METADATA)
    cargs = []
    cargs.append("recon-all")
    cargs.extend([
        "-subjid",
        subjid
    ])
    cargs.append(process_directive)
    if hemi_flag is not None:
        cargs.extend([
            "-hemi",
            hemi_flag
        ])
    if expert_prefs_file is not None:
        cargs.extend([
            "-expert",
            execution.input_file(expert_prefs_file)
        ])
    if xopts_use:
        cargs.append("-xopts-use")
    if xopts_clean:
        cargs.append("-xopts-clean")
    if xopts_overwrite:
        cargs.append("-xopts-overwrite")
    if watershed_cmd is not None:
        cargs.extend([
            "-watershed",
            watershed_cmd
        ])
    if xmask_file is not None:
        cargs.extend([
            "-xmask",
            execution.input_file(xmask_file)
        ])
    if wsless:
        cargs.append("-wsless")
    if wsmore:
        cargs.append("-wsmore")
    if wsatlas:
        cargs.append("-wsatlas")
    if no_wsatlas:
        cargs.append("-no-wsatlas")
    if no_wsgcaatlas:
        cargs.append("-no-wsgcaatlas")
    if wsthresh is not None:
        cargs.extend([
            "-wsthresh",
            str(wsthresh)
        ])
    if wsseed is not None:
        cargs.extend([
            "-wsseed",
            wsseed
        ])
    if norm3diters is not None:
        cargs.extend([
            "-norm3diters",
            str(norm3diters)
        ])
    if normmaxgrad is not None:
        cargs.extend([
            "-normmaxgrad",
            str(normmaxgrad)
        ])
    if norm1_b is not None:
        cargs.extend([
            "-norm1-b",
            str(norm1_b)
        ])
    if norm2_b is not None:
        cargs.extend([
            "-norm2-b",
            str(norm2_b)
        ])
    if norm1_n is not None:
        cargs.extend([
            "-norm1-n",
            str(norm1_n)
        ])
    if norm2_n is not None:
        cargs.extend([
            "-norm2-n",
            str(norm2_n)
        ])
    if cm_flag:
        cargs.append("-cm")
    if no_fix_with_ga:
        cargs.append("-no-fix-with-ga")
    if fix_diag_only:
        cargs.append("-fix-diag-only")
    if seg_wlo is not None:
        cargs.extend([
            "-seg-wlo",
            str(seg_wlo)
        ])
    if seg_ghi is not None:
        cargs.extend([
            "-seg-ghi",
            str(seg_ghi)
        ])
    if nothicken:
        cargs.append("-nothicken")
    if no_ca_align_after:
        cargs.append("-no-ca-align-after")
    if no_ca_align:
        cargs.append("-no-ca-align")
    if deface:
        cargs.append("-deface")
    if mprage:
        cargs.append("-mprage")
    if washu_mprage:
        cargs.append("-washu_mprage")
    if schwartzya3t_atlas:
        cargs.append("-schwartzya3t-atlas")
    if mail_username is not None:
        cargs.extend([
            "-mail",
            mail_username
        ])
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    ret = MapCentralSulcusOutputs(
        root=execution.output_file("."),
        log_file=execution.output_file(subjid + "/scripts/recon-all.log"),
        status_log_file=execution.output_file(subjid + "/scripts/recon-all-status.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_CENTRAL_SULCUS_METADATA",
    "MapCentralSulcusOutputs",
    "map_central_sulcus",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CLUST_EXP_STAT_PARSE_PY_METADATA = Metadata(
    id="0ee922f117a5e881955bf4f23aba845f4aef47bb.boutiques",
    name="ClustExp_StatParse.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ClustExpStatParsePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `clust_exp_stat_parse_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    table_mean: OutputPathType | None
    """Table with all data extracted from all subjects."""
    group_table: OutputPathType | None
    """Table with information parsed from the statistics data set history."""
    v_3dclust_output: OutputPathType | None
    """Output directly from 3dclust."""
    clusters_output: OutputPathType | None
    """Cleaned up version of the whereami output."""
    statinfo_output: OutputPathType | None
    """Summary info for the shiny app."""
    thresholded_dataset: OutputPathType | None
    """A new data set from input statistics, thresholded at uncorrected p
    value."""
    thresholded_mask_dataset: OutputPathType | None
    """Integer labeled mask of the thresholded image with cluster sizes at least
    as big as the -MinVox."""
    master_copy: OutputPathType | None
    """A NIfTI copy of the master file provided that may have been resampled."""


def clust_exp_stat_parse_py(
    statdset: InputPathType,
    meanbrik: float,
    threshbrik: float,
    subjdset: InputPathType,
    subjtable: InputPathType,
    master: InputPathType,
    prefix: str | None = None,
    pval: float | None = None,
    minvox: float | None = None,
    atlas: str | None = None,
    session: str | None = None,
    noshiny: bool = False,
    overwrite: bool = False,
    runner: Runner | None = None,
) -> ClustExpStatParsePyOutputs:
    """
    Parser for statistical data sets and subject data sets, generating several
    outputs for further analysis.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        statdset: Statistics dataset.
        meanbrik: Mean subbrik (integer >= 0).
        threshbrik: Threshold subbrik. Might be the same as MeanBrik (integer\
            >= 0).
        subjdset: Labeled dataset with all subjects (from @ClustExp_CatLab).
        subjtable: Table with subject labels and input datasets.
        master: Master data set for underlay.
        prefix: Name for output (no path).
        pval: Uncorrected p value for thresholding.
        minvox: Minimum voxels in cluster.
        atlas: Atlas name for lookup (list at: whereami -help).
        session: Output parent folder if you don't want the current working\
            directory.
        noshiny: Do not create shiny app.
        overwrite: Remove previous folder with same PREFIX.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ClustExpStatParsePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CLUST_EXP_STAT_PARSE_PY_METADATA)
    cargs = []
    cargs.append("ClustExp_StatParse.py")
    cargs.extend([
        "-StatDSET",
        execution.input_file(statdset)
    ])
    cargs.extend([
        "-MeanBrik",
        str(meanbrik)
    ])
    cargs.extend([
        "-ThreshBrik",
        str(threshbrik)
    ])
    cargs.extend([
        "-SubjDSET",
        execution.input_file(subjdset)
    ])
    cargs.extend([
        "-SubjTable",
        execution.input_file(subjtable)
    ])
    cargs.extend([
        "-master",
        execution.input_file(master)
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if pval is not None:
        cargs.extend([
            "-p",
            str(pval)
        ])
    if minvox is not None:
        cargs.extend([
            "-MinVox",
            str(minvox)
        ])
    if atlas is not None:
        cargs.extend([
            "-atlas",
            atlas
        ])
    if session is not None:
        cargs.extend([
            "-session",
            session
        ])
    if noshiny:
        cargs.append("-NoShiny")
    if overwrite:
        cargs.append("-overwrite")
    ret = ClustExpStatParsePyOutputs(
        root=execution.output_file("."),
        table_mean=execution.output_file(prefix + "_p_uncor_" + str(pval) + "_mean.csv") if (prefix is not None and pval is not None) else None,
        group_table=execution.output_file(prefix + "_GroupTable.csv") if (prefix is not None) else None,
        v_3dclust_output=execution.output_file(prefix + "_p_uncor_" + str(pval) + "_3dclust.1D") if (prefix is not None and pval is not None) else None,
        clusters_output=execution.output_file(prefix + "_p_uncor_" + str(pval) + "_clusters.csv") if (prefix is not None and pval is not None) else None,
        statinfo_output=execution.output_file(prefix + "_StatInfo.csv") if (prefix is not None) else None,
        thresholded_dataset=execution.output_file(prefix + "_p_uncor_" + str(pval) + ".nii.gz") if (prefix is not None and pval is not None) else None,
        thresholded_mask_dataset=execution.output_file(prefix + "_p_uncor_" + str(pval) + "_mask.nii.gz") if (prefix is not None and pval is not None) else None,
        master_copy=execution.output_file(prefix + "_master.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CLUST_EXP_STAT_PARSE_PY_METADATA",
    "ClustExpStatParsePyOutputs",
    "clust_exp_stat_parse_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DRETROICOR_METADATA = Metadata(
    id="0b8e3bbd9eaa6f16498a0393158cdcd367502347.boutiques",
    name="3dretroicor",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dretroicorOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dretroicor(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_dataset: OutputPathType | None
    """Corrected dataset output."""
    output_cardiac_phase: OutputPathType | None
    """Cardiac phase output file."""
    output_resp_phase: OutputPathType | None
    """Respiratory phase output file."""


def v_3dretroicor(
    dataset: InputPathType,
    ignore: float | None = None,
    prefix: str | None = None,
    card: InputPathType | None = None,
    cardphase: str | None = None,
    threshold: float | None = None,
    resp: InputPathType | None = None,
    respphase: str | None = None,
    order: float | None = None,
    runner: Runner | None = None,
) -> V3dretroicorOutputs:
    """
    Performs Retrospective Image Correction for physiological motion effects using a
    modified RETROICOR algorithm.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: 3D+time dataset to process.
        ignore: The number of initial timepoints to ignore in the input. These\
            points will be passed through uncorrected.
        prefix: Prefix for new, corrected dataset.
        card: 1D cardiac data file for cardiac correction.
        cardphase: Filename for 1D cardiac phase output.
        threshold: Threshold for detection of R-wave peaks in input. Make sure\
            it's above the background noise level; try 3/4 or 4/5 times range plus\
            minimum.
        resp: 1D respiratory waveform data for correction.
        respphase: Filename for 1D respiratory phase output.
        order: The order of the correction. Higher-order terms yield little\
            improvement according to Glover et al.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dretroicorOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DRETROICOR_METADATA)
    cargs = []
    cargs.append("3dretroicor")
    if ignore is not None:
        cargs.extend([
            "-ignore",
            str(ignore)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if card is not None:
        cargs.extend([
            "-card",
            execution.input_file(card)
        ])
    if cardphase is not None:
        cargs.extend([
            "-cardphase",
            cardphase
        ])
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if resp is not None:
        cargs.extend([
            "-resp",
            execution.input_file(resp)
        ])
    if respphase is not None:
        cargs.extend([
            "-respphase",
            respphase
        ])
    if order is not None:
        cargs.extend([
            "-order",
            str(order)
        ])
    cargs.append(execution.input_file(dataset))
    ret = V3dretroicorOutputs(
        root=execution.output_file("."),
        corrected_dataset=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        output_cardiac_phase=execution.output_file(cardphase) if (cardphase is not None) else None,
        output_resp_phase=execution.output_file(respphase) if (respphase is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dretroicorOutputs",
    "V_3DRETROICOR_METADATA",
    "v_3dretroicor",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_PATHSTATS_METADATA = Metadata(
    id="8110c02ff2c74fe994c5787d89b13efd80585a6a.boutiques",
    name="dmri_pathstats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriPathstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_pathstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Text file for overall path measures"""
    out_vox_file: OutputPathType | None
    """Text file for voxel-by-voxel measures along path"""
    median_file: OutputPathType | None
    """.trk file of median streamline"""


def dmri_pathstats(
    intrk: InputPathType,
    intrc: InputPathType,
    rois: list[InputPathType] | None = None,
    meas: list[InputPathType] | None = None,
    measname: list[str] | None = None,
    dtbase: str | None = None,
    path: str | None = None,
    subj: str | None = None,
    out: str | None = None,
    outvox: str | None = None,
    median: InputPathType | None = None,
    ends: str | None = None,
    ref: InputPathType | None = None,
    pthr: float | None = None,
    fthr: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DmriPathstatsOutputs:
    """
    Compute path statistics for diffusion MRI data based on input .trk file and
    optional various measures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        intrk: Input .trk file.
        intrc: Input tracula directory.
        rois: Input labeling ROIs for .trk file (optional).
        meas: Input microstructural measure volume(s) (optional).
        measname: Name(s) of microstructural measure(s) (as many as volumes).
        dtbase: Base name of input dtifit volumes (optional).
        path: Name of pathway (optional, written to output files).
        subj: Name of subject (optional, written to output files).
        out: Output text file for overall path measures.
        outvox: Output text file for voxel-by-voxel measures along path\
            (optional).
        median: Output .trk file of median streamline (optional).
        ends: Base name of output volumes of streamline ends (optional).
        ref: Reference volume (needed only if using --ends without --dtbase).
        pthr: Lower threshold on path posterior distribution, as a portion of\
            the maximum (range: 0-1, default: 0.2).
        fthr: Lower threshold on FA (range: 0-1, default: no threshold).
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriPathstatsOutputs`).
    """
    if rois is not None and not (0 <= len(rois)): 
        raise ValueError(f"Length of 'rois' must be greater than 0 but was {len(rois)}")
    if meas is not None and not (0 <= len(meas)): 
        raise ValueError(f"Length of 'meas' must be greater than 0 but was {len(meas)}")
    if measname is not None and not (0 <= len(measname)): 
        raise ValueError(f"Length of 'measname' must be greater than 0 but was {len(measname)}")
    if pthr is not None and not (0 <= pthr <= 1): 
        raise ValueError(f"'pthr' must be between 0 <= x <= 1 but was {pthr}")
    if fthr is not None and not (0 <= fthr <= 1): 
        raise ValueError(f"'fthr' must be between 0 <= x <= 1 but was {fthr}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_PATHSTATS_METADATA)
    cargs = []
    cargs.append("./dmri_pathstats")
    cargs.extend([
        "--intrk",
        execution.input_file(intrk)
    ])
    if rois is not None:
        cargs.extend([
            "--rois",
            *[execution.input_file(f) for f in rois]
        ])
    cargs.extend([
        "--intrc",
        execution.input_file(intrc)
    ])
    if meas is not None:
        cargs.extend([
            "--meas",
            *[execution.input_file(f) for f in meas]
        ])
    if measname is not None:
        cargs.extend([
            "--measname",
            *measname
        ])
    if dtbase is not None:
        cargs.extend([
            "--dtbase",
            dtbase
        ])
    if path is not None:
        cargs.extend([
            "--path",
            path
        ])
    if subj is not None:
        cargs.extend([
            "--subj",
            subj
        ])
    if out is not None:
        cargs.extend([
            "--out",
            out
        ])
    if outvox is not None:
        cargs.extend([
            "--outvox",
            outvox
        ])
    if median is not None:
        cargs.extend([
            "--median",
            execution.input_file(median)
        ])
    if ends is not None:
        cargs.extend([
            "--ends",
            ends
        ])
    if ref is not None:
        cargs.extend([
            "--ref",
            execution.input_file(ref)
        ])
    if pthr is not None:
        cargs.extend([
            "--pthr",
            str(pthr)
        ])
    if fthr is not None:
        cargs.extend([
            "--fthr",
            str(fthr)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = DmriPathstatsOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(out) if (out is not None) else None,
        out_vox_file=execution.output_file(outvox) if (outvox is not None) else None,
        median_file=execution.output_file(pathlib.Path(median).name) if (median is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_PATHSTATS_METADATA",
    "DmriPathstatsOutputs",
    "dmri_pathstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BALL_MATCH_METADATA = Metadata(
    id="fe3fd0a09e1cb0531678dcf999710e6d7163d194.boutiques",
    name="3dBallMatch",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBallMatchOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_ball_match(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_stdout: OutputPathType
    """Output containing matching coordinates and related data"""


def v_3d_ball_match(
    input_dataset: InputPathType,
    radius: float | None = None,
    dataset_option: str | None = None,
    ball_radius: float | None = None,
    spheroid_axes: list[float] | None = None,
    runner: Runner | None = None,
) -> V3dBallMatchOutputs:
    """
    A tool to find a good match between a ball (filled sphere) of the given radius
    and a dataset to determine a crude approximate center of the brain quickly.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset (e.g., Fred.nii).
        radius: Radius of the 3D ball to match (in mm).
        dataset_option: Specifies the input dataset.
        ball_radius: Set the radius of the 3D ball to match (mm).
        spheroid_axes: Match with a spheroid of revolution, with principal axis\
            radius 'a' and secondary axes radii 'b'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBallMatchOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BALL_MATCH_METADATA)
    cargs = []
    cargs.append("3dBallMatch")
    cargs.append(execution.input_file(input_dataset))
    if radius is not None:
        cargs.append(str(radius))
    if dataset_option is not None:
        cargs.extend([
            "-input",
            dataset_option
        ])
    if ball_radius is not None:
        cargs.extend([
            "-ball",
            str(ball_radius)
        ])
    if spheroid_axes is not None:
        cargs.extend([
            "-spheroid",
            *map(str, spheroid_axes)
        ])
    ret = V3dBallMatchOutputs(
        root=execution.output_file("."),
        output_stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBallMatchOutputs",
    "V_3D_BALL_MATCH_METADATA",
    "v_3d_ball_match",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TKSURFERFV_METADATA = Metadata(
    id="5f6c49af2e657ea2532d217b90ff0a44fe817bc6.boutiques",
    name="tksurferfv",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TksurferfvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tksurferfv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tksurferfv(
    subject: str,
    hemi: str,
    surface: str,
    tksurfer: bool = False,
    all_surfaces: bool = False,
    vgl: bool = False,
    no_vgl: bool = False,
    no_outline: bool = False,
    neuro_orientation: bool = False,
    rotate_around_cursor: bool = False,
    heat_scale: str | None = "min_to_max",
    runner: Runner | None = None,
) -> TksurferfvOutputs:
    """
    A script that runs freeview with arguments similar to tksurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        hemi: Hemisphere (e.g., lh or rh).
        surface: Surface type.
        tksurfer: Use tksurfer instead of freeview.
        all_surfaces: Load white, pial, and inflated surfaces.
        vgl: Run freeview with /usr/pubsw/bin/vglrun.
        no_vgl: Do not run freeview with /usr/pubsw/bin/vglrun.
        no_outline: Do not show annotations as outlines.
        neuro_orientation: Use neurological orientation instead of\
            radiological.
        rotate_around_cursor: Rotate around cursor in 3D view.
        heat_scale: Overlay heat scale (options: linear, linearopaque,\
            piecewise, min_to_max).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TksurferfvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TKSURFERFV_METADATA)
    cargs = []
    cargs.append("tksurferfv")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(surface)
    if tksurfer:
        cargs.append("-tksurfer")
    if all_surfaces:
        cargs.append("-all")
    if vgl:
        cargs.append("-vgl")
    if no_vgl:
        cargs.append("-no-vgl")
    if no_outline:
        cargs.append("-no-outline")
    if neuro_orientation:
        cargs.append("-neuro")
    if rotate_around_cursor:
        cargs.append("-rca")
    if heat_scale is not None:
        cargs.append(heat_scale)
    ret = TksurferfvOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TKSURFERFV_METADATA",
    "TksurferfvOutputs",
    "tksurferfv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TALAIRACH_AFD_METADATA = Metadata(
    id="67c851628b7054378003054a4565ed1deba97379.boutiques",
    name="talairach_afd",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalairachAfdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `talairach_afd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def talairach_afd(
    subject_name: str | None = None,
    xfm_file: InputPathType | None = None,
    p_value_threshold: float | None = 0.01,
    afd_directory: str | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> TalairachAfdOutputs:
    """
    Detects Talairach alignment failures.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Specify subject's name.
        xfm_file: Specify the talairach.xfm file to check.
        p_value_threshold: Threshold the p-values at #; Talairach transforms\
            for subjects with p-values <= T are considered as very unlikely.
        afd_directory: Specify directory containing .afd data files.
        verbose: Enable verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalairachAfdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TALAIRACH_AFD_METADATA)
    cargs = []
    cargs.append("talairach_afd")
    if subject_name is not None:
        cargs.extend([
            "-subj",
            subject_name
        ])
    if xfm_file is not None:
        cargs.extend([
            "-xfm",
            execution.input_file(xfm_file)
        ])
    if p_value_threshold is not None:
        cargs.extend([
            "-T",
            str(p_value_threshold)
        ])
    if afd_directory is not None:
        cargs.extend([
            "-afd",
            afd_directory
        ])
    if verbose:
        cargs.append("-V")
    ret = TalairachAfdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TALAIRACH_AFD_METADATA",
    "TalairachAfdOutputs",
    "talairach_afd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WMSASEG_METADATA = Metadata(
    id="70413a8a1c01bd4a41bdede39664427061f28431.boutiques",
    name="wmsaseg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class WmsasegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `wmsaseg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    t1_canorm: OutputPathType | None
    """CA normalized T1 output"""
    wmsa_lta: OutputPathType | None
    """Linear transform to average space"""


def wmsaseg(
    subject: str,
    source_orig: str | None = None,
    source_long: bool = False,
    output_subdir: str | None = None,
    gca_file: InputPathType | None = None,
    no_reg: bool = False,
    no_canorm: bool = False,
    init_spm: bool = False,
    reg_only: bool = False,
    halo1: bool = False,
    halo2: bool = False,
    runner: Runner | None = None,
) -> WmsasegOutputs:
    """
    White Matter Hyperintensity Segmentation Tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        source_orig: Use T2 and PD images from original subject.
        source_long: Use T2 and PD images from longitudinal subject.
        output_subdir: Output subdirectory name (default is wmsa).
        gca_file: GCA file path.
        no_reg: Do not register mode to anatomical image.
        no_canorm: Do not run mri_ca_normalize.
        init_spm: Initialize SPM (default is FSL).
        reg_only: Only perform registration.
        halo1: Halo 1 option.
        halo2: Halo 2 option.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WmsasegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WMSASEG_METADATA)
    cargs = []
    cargs.append("wmsaseg")
    cargs.extend([
        "-s",
        "-" + subject
    ])
    if source_orig is not None:
        cargs.extend([
            "--s+orig",
            source_orig
        ])
    if source_long:
        cargs.append("--s+long")
    if output_subdir is not None:
        cargs.extend([
            "--sub",
            output_subdir
        ])
    if gca_file is not None:
        cargs.extend([
            "--gca",
            execution.input_file(gca_file)
        ])
    if no_reg:
        cargs.append("--no-reg")
    if no_canorm:
        cargs.append("--no-canorm")
    if init_spm:
        cargs.append("--init-spm")
    if reg_only:
        cargs.append("--reg-only")
    if halo1:
        cargs.append("--halo1")
    if halo2:
        cargs.append("--halo2")
    ret = WmsasegOutputs(
        root=execution.output_file("."),
        t1_canorm=execution.output_file(output_subdir + "/T1.canorm.mgz") if (output_subdir is not None) else None,
        wmsa_lta=execution.output_file(output_subdir + "/wmsa.lta") if (output_subdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WMSASEG_METADATA",
    "WmsasegOutputs",
    "wmsaseg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBFIELDS_T1_LONGITUDINAL_METADATA = Metadata(
    id="255cbc9bcd0a4cdb77830871dfed14d27befa862.boutiques",
    name="SegmentSubfieldsT1Longitudinal",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubfieldsT1LongitudinalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subfields_t1_longitudinal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segmentation_output: OutputPathType
    """Output file containing the segmented subfields"""


def segment_subfields_t1_longitudinal(
    subject_id: str,
    input_image: InputPathType,
    output_dir: str,
    runner: Runner | None = None,
) -> SegmentSubfieldsT1LongitudinalOutputs:
    """
    FreeSurfer tool for segmenting subfields in longitudinal T1-weighted images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject ID for the longitudinal analysis.
        input_image: Input T1-weighted image.
        output_dir: Directory to save the output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubfieldsT1LongitudinalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBFIELDS_T1_LONGITUDINAL_METADATA)
    cargs = []
    cargs.append("SegmentSubfieldsT1Longitudinal")
    cargs.append(subject_id)
    cargs.append(execution.input_file(input_image))
    cargs.append(output_dir)
    ret = SegmentSubfieldsT1LongitudinalOutputs(
        root=execution.output_file("."),
        segmentation_output=execution.output_file(output_dir + "/subfields_segmentation.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBFIELDS_T1_LONGITUDINAL_METADATA",
    "SegmentSubfieldsT1LongitudinalOutputs",
    "segment_subfields_t1_longitudinal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SPHARM_EXAMPLES_METADATA = Metadata(
    id="7b9dbc8f033f538b7638320e8d57980c476bb1cc.boutiques",
    name="@Spharm.examples",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSpharmExamplesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__spharm_examples(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__spharm_examples(
    help_web: bool = False,
    help_web_alias: bool = False,
    help_view: bool = False,
    help_view_alias: bool = False,
    all_opts: bool = False,
    help_find: str | None = None,
    runner: Runner | None = None,
) -> VSpharmExamplesOutputs:
    """
    A script to demonstrate the usage of spherical harmonics decomposition with
    SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        help_web: Open webpage with help for this program.
        help_web_alias: Same as -h_web.
        help_view: Open -help output in a GUI editor.
        help_view_alias: Same as -h_view.
        all_opts: List all of the options for this script.
        help_find: Search for lines containing WORD in -help output. Search is\
            approximate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSpharmExamplesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SPHARM_EXAMPLES_METADATA)
    cargs = []
    cargs.append("@Spharm.examples")
    if help_web:
        cargs.append("-h_web")
    if help_web_alias:
        cargs.append("-hweb")
    if help_view:
        cargs.append("-h_view")
    if help_view_alias:
        cargs.append("-hview")
    if all_opts:
        cargs.append("-all_opts")
    if help_find is not None:
        cargs.extend([
            "-h_find",
            help_find
        ])
    ret = VSpharmExamplesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSpharmExamplesOutputs",
    "V__SPHARM_EXAMPLES_METADATA",
    "v__spharm_examples",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_TO_VOLUME_MAPPING_METADATA = Metadata(
    id="ae19948841cc9f986f2043fabc666ed7d6114d97.boutiques",
    name="label-to-volume-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class LabelToVolumeMappingRibbonConstrained:
    """
    use ribbon constrained mapping algorithm.
    """
    inner_surf: InputPathType
    """the inner surface of the ribbon"""
    outer_surf: InputPathType
    """the outer surface of the ribbon"""
    opt_voxel_subdiv_subdiv_num: int | None = None
    """voxel divisions while estimating voxel weights: number of subdivisions,
    default 3"""
    opt_greedy: bool = False
    """also put labels in voxels with less than 50% partial volume (legacy
    behavior)"""
    opt_thick_columns: bool = False
    """use overlapping columns (legacy method)"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-ribbon-constrained")
        cargs.append(execution.input_file(self.inner_surf))
        cargs.append(execution.input_file(self.outer_surf))
        if self.opt_voxel_subdiv_subdiv_num is not None:
            cargs.extend([
                "-voxel-subdiv",
                str(self.opt_voxel_subdiv_subdiv_num)
            ])
        if self.opt_greedy:
            cargs.append("-greedy")
        if self.opt_thick_columns:
            cargs.append("-thick-columns")
        return cargs


class LabelToVolumeMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_to_volume_mapping(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume file"""


def label_to_volume_mapping(
    label: InputPathType,
    surface: InputPathType,
    volume_space: InputPathType,
    volume_out: str,
    opt_nearest_vertex_distance: float | None = None,
    ribbon_constrained: LabelToVolumeMappingRibbonConstrained | None = None,
    runner: Runner | None = None,
) -> LabelToVolumeMappingOutputs:
    """
    Map label file to volume.
    
    Maps labels from a gifti label file into a volume file. You must specify
    exactly one mapping method option. The -nearest-vertex method uses the label
    from the vertex closest to the voxel center. The -ribbon-constrained method
    uses the same method as in -volume-to-surface-mapping, then uses the weights
    in reverse, with popularity logic to decide on a label to use.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label: the input label file.
        surface: the surface to use coordinates from.
        volume_space: a volume file in the desired output volume space.
        volume_out: the output volume file.
        opt_nearest_vertex_distance: use the label from the vertex closest to\
            the voxel center: how far from the surface to map labels to voxels, in\
            mm.
        ribbon_constrained: use ribbon constrained mapping algorithm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToVolumeMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_TO_VOLUME_MAPPING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-to-volume-mapping")
    cargs.append(execution.input_file(label))
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(volume_space))
    cargs.append(volume_out)
    if opt_nearest_vertex_distance is not None:
        cargs.extend([
            "-nearest-vertex",
            str(opt_nearest_vertex_distance)
        ])
    if ribbon_constrained is not None:
        cargs.extend(ribbon_constrained.run(execution))
    ret = LabelToVolumeMappingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_TO_VOLUME_MAPPING_METADATA",
    "LabelToVolumeMappingOutputs",
    "LabelToVolumeMappingRibbonConstrained",
    "label_to_volume_mapping",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMAGE_SET_STATISTICS_METADATA = Metadata(
    id="9329b484e2f67dba69c548b9b9a373ea2a072aa8.boutiques",
    name="ImageSetStatistics",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class ImageSetStatisticsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `image_set_statistics(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    computed_statistics_image: OutputPathType
    """The output image containing the computed statistics."""


def image_set_statistics(
    image_dimension: int,
    controls_list: InputPathType,
    output_image: str,
    which_stat: typing.Literal[0, 1, 2, 3, 4, 5, 6, 7],
    roi: InputPathType | None = None,
    imagelist2: InputPathType | None = None,
    runner: Runner | None = None,
) -> ImageSetStatisticsOutputs:
    """
    ImageSetStatistics computes statistics from a set of images. The whichstat
    option defines the type of statistic to compute, ranging from median to
    similarity-weighted metrics.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the images to be processed by\
            ImageSetStatistics.
        controls_list: Text file containing the list of control images.
        output_image: The output image file where the computed statistics are\
            stored.
        which_stat: Choice of statistic to compute: 0 for median, 1 for max\
            probability appearance, 2 for weighted mean appearance, 3 for trimmed\
            mean, 4 for max value, 5 for similarity-weighted (requires imagelist2),\
            6 for best local match label, 7 for max value from ROI.
        roi: Region of interest image file, optional depending on the whichstat\
            option.
        imagelist2: List of similarity images used for similarity-weighted\
            statistics. Required if whichstat equals 5 or 6.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImageSetStatisticsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMAGE_SET_STATISTICS_METADATA)
    cargs = []
    cargs.append("ImageSetStatistics")
    cargs.append(str(image_dimension))
    cargs.extend([
        "[CONTROLS_LIST]",
        execution.input_file(controls_list)
    ])
    cargs.extend([
        "[OUTPUT_IMAGE]",
        output_image
    ])
    cargs.extend([
        "[WHICH_STAT]",
        str(which_stat)
    ])
    if roi is not None:
        cargs.extend([
            "[ROI]",
            execution.input_file(roi)
        ])
    if imagelist2 is not None:
        cargs.extend([
            "[IMAGELIST2]",
            execution.input_file(imagelist2)
        ])
    ret = ImageSetStatisticsOutputs(
        root=execution.output_file("."),
        computed_statistics_image=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMAGE_SET_STATISTICS_METADATA",
    "ImageSetStatisticsOutputs",
    "image_set_statistics",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICEANIMATE_METADATA = Metadata(
    id="05268b7eca1ce9802cba56c1e5171a4d5003db1c.boutiques",
    name="sliceanimate",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SliceanimateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sliceanimate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    animated_gif: OutputPathType
    """Generated animated GIF"""


def sliceanimate(
    output_file: str,
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> SliceanimateOutputs:
    """
    A tool for animating slices of an image using whirlgif.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        output_file: Output animated GIF file.
        input_files: Input image files for animation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SliceanimateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICEANIMATE_METADATA)
    cargs = []
    cargs.append("sliceanimate")
    cargs.append(output_file)
    cargs.append("--")
    cargs.extend([execution.input_file(f) for f in input_files])
    ret = SliceanimateOutputs(
        root=execution.output_file("."),
        animated_gif=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICEANIMATE_METADATA",
    "SliceanimateOutputs",
    "sliceanimate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_FOLDING_ATLAS_METADATA = Metadata(
    id="cd742cf69eb865650042165331953a619d588ea9.boutiques",
    name="make_folding_atlas",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeFoldingAtlasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_folding_atlas(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    average_subject_folder: OutputPathType | None
    """Average subject folder that contains the atlas files for each
    iteration."""


def make_folding_atlas(
    subjlistfile: InputPathType | None = None,
    fsgdfile: InputPathType | None = None,
    subjects: list[str] | None = None,
    output_base: str | None = None,
    max_iterations: float | None = None,
    xhemi: bool = False,
    init_surf_reg: str | None = None,
    init_subject: str | None = None,
    no_annot_template: bool = False,
    right_hemisphere: bool = False,
    lhrh: bool = False,
    ico_order: float | None = None,
    no_vol_on_last: bool = False,
    vol: bool = False,
    init: bool = False,
    short_sleep: bool = False,
    no_template_only: bool = False,
    threads: float | None = None,
    slurm_account: str | None = None,
    runner: Runner | None = None,
) -> MakeFoldingAtlasOutputs:
    """
    Script to iteratively create a cortical folding atlas.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjlistfile: Subject list file.
        fsgdfile: FS Gradient Design file.
        subjects: Subjects to be included.
        output_base: Output base; the subject will be named based on this.
        max_iterations: Maximum number of iterations.
        xhemi: Do xhemi (sets hemilist to lh only, use --lhrh after if both are\
            wanted).
        init_surf_reg: Registration used to make template on first iteration\
            (default sphere.reg).
        init_subject: Create first atlas from subject instead of all subjects.
        no_annot_template: Disable annotation template (good for monkeys).
        right_hemisphere: Process right hemisphere.
        lhrh: Process both left and right hemispheres (default).
        ico_order: Icosahedron order; default is 7.
        no_vol_on_last: Do not run make_average_volume on the last iteration.
        vol: Run make_average_volume on each iteration.
        init: Use previous iteration registration to initialize\
            mris_register/surfreg.
        short_sleep: Sleep for a shorter time before polling.
        no_template_only: Make average surface files even with a single hemi or\
            --no-vol.
        threads: Number of threads to use.
        slurm_account: SLURM account or set FS_BATCH_ACCOUNT environment\
            variable.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeFoldingAtlasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_FOLDING_ATLAS_METADATA)
    cargs = []
    cargs.append("make_folding_atlas")
    if subjlistfile is not None:
        cargs.extend([
            "--f",
            execution.input_file(subjlistfile)
        ])
    if fsgdfile is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgdfile)
        ])
    if subjects is not None:
        cargs.extend([
            "--s",
            *subjects
        ])
    if output_base is not None:
        cargs.extend([
            "--b",
            output_base
        ])
    if max_iterations is not None:
        cargs.extend([
            "--nmax",
            str(max_iterations)
        ])
    if xhemi:
        cargs.append("--xhemi")
    if init_surf_reg is not None:
        cargs.extend([
            "--init-surf-reg",
            init_surf_reg
        ])
    if init_subject is not None:
        cargs.extend([
            "--init-subject",
            init_subject
        ])
    if no_annot_template:
        cargs.append("--no-annot-template")
    if right_hemisphere:
        cargs.append("--rh")
    if lhrh:
        cargs.append("--lhrh")
    if ico_order is not None:
        cargs.extend([
            "--ico",
            str(ico_order)
        ])
    if no_vol_on_last:
        cargs.append("--no-vol-on-last")
    if vol:
        cargs.append("--vol")
    if init:
        cargs.append("--init")
    if short_sleep:
        cargs.append("--short-sleep")
    if no_template_only:
        cargs.append("--no-template-only")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if slurm_account is not None:
        cargs.extend([
            "--account",
            slurm_account
        ])
    ret = MakeFoldingAtlasOutputs(
        root=execution.output_file("."),
        average_subject_folder=execution.output_file(output_base + ".i*") if (output_base is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_FOLDING_ATLAS_METADATA",
    "MakeFoldingAtlasOutputs",
    "make_folding_atlas",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_EVALUATE_MORPH_METADATA = Metadata(
    id="80d2aca899795eab8a40cb4bb8b3d34e4bf9970e.boutiques",
    name="mri_evaluate_morph",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriEvaluateMorphOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_evaluate_morph(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_overlap_file: OutputPathType
    """The output file containing overlap results."""


def mri_evaluate_morph(
    xform_name: InputPathType,
    segmentation_files: list[InputPathType],
    output_file: str,
    runner: Runner | None = None,
) -> MriEvaluateMorphOutputs:
    """
    This program computes the overlap of a set of segmentations for a given morph
    using an xform file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        xform_name: Transformation file name.
        segmentation_files: Input segmentation files.
        output_file: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriEvaluateMorphOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_EVALUATE_MORPH_METADATA)
    cargs = []
    cargs.append("mri_evaluate_morph")
    cargs.append(execution.input_file(xform_name))
    cargs.extend([execution.input_file(f) for f in segmentation_files])
    cargs.append(output_file)
    ret = MriEvaluateMorphOutputs(
        root=execution.output_file("."),
        output_overlap_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_EVALUATE_MORPH_METADATA",
    "MriEvaluateMorphOutputs",
    "mri_evaluate_morph",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PRINT_UNIQUE_LABELS_CSH_METADATA = Metadata(
    id="e9fb80f03f3d4d6c2fbe65561d9c32f6e16bc580.boutiques",
    name="print_unique_labels.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class PrintUniqueLabelsCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `print_unique_labels_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    results_file: OutputPathType
    """Output file with the list of unique labels"""


def print_unique_labels_csh(
    label_volume: InputPathType,
    list_only: bool = False,
    runner: Runner | None = None,
) -> PrintUniqueLabelsCshOutputs:
    """
    Prints the list of unique labels (with structure name) in the input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label_volume: Label volume to be analyzed.
        list_only: Only list the labels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PrintUniqueLabelsCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PRINT_UNIQUE_LABELS_CSH_METADATA)
    cargs = []
    cargs.append("print_unique_labels.csh")
    cargs.extend([
        "--vol",
        execution.input_file(label_volume)
    ])
    if list_only:
        cargs.append("--list")
    ret = PrintUniqueLabelsCshOutputs(
        root=execution.output_file("."),
        results_file=execution.output_file("[OUTPUT_FILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PRINT_UNIQUE_LABELS_CSH_METADATA",
    "PrintUniqueLabelsCshOutputs",
    "print_unique_labels_csh",
]



"""
MRTrix3

MRtrix3 provides a set of tools to perform various types of diffusion MRI
analyses, from various forms of tractography through to next-generation
group-level analyses. It is designed with consistency, performance, and
stability in mind, and is freely available under an open-source license. It is
developed and maintained by a team of experts in the field, fostering an active
community of users from diverse backgrounds.

URL: https://www.mrtrix.org/
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .afdconnectivity import *
from .amp2response import *
from .amp2sh import *
from .connectome2tck import *
from .connectomeedit import *
from .connectomestats import *
from .dcmedit import *
from .dcminfo import *
from .dirflip import *
from .dirgen import *
from .dirmerge import *
from .dirorder import *
from .dirsplit import *
from .dirstat import *
from .dwi2adc import *
from .dwi2fod import *
from .dwi2mask import *
from .dwi2response import *
from .dwi2tensor import *
from .dwibiascorrect import *
from .dwidenoise import *
from .dwiextract import *
from .dwigradcheck import *
from .fixel2peaks import *
from .fixel2sh import *
from .fixel2tsf import *
from .fixel2voxel import *
from .fixelcfestats import *
from .fixelconnectivity import *
from .fixelconvert import *
from .fixelcorrespondence import *
from .fixelcrop import *
from .fixelfilter import *
from .fixelreorient import *
from .fod2dec import *
from .fod2fixel import *
from .label2colour import *
from .label2mesh import *
from .labelconvert import *
from .labelstats import *
from .maskdump import *
from .maskfilter import *
from .mesh2voxel import *
from .meshconvert import *
from .meshfilter import *
from .mraverageheader import *
from .mrcalc import *
from .mrcat import *
from .mrcentroid import *
from .mrcheckerboardmask import *
from .mrclusterstats import *
from .mrcolour import *
from .mrconvert import *
from .mrdegibbs import *
from .mrdump import *
from .mredit import *
from .mrfilter import *
from .mrgrid import *
from .mrhistmatch import *
from .mrhistogram import *
from .mrinfo import *
from .mrmath import *
from .mrmetric import *
from .mrregister import *
from .mrstats import *
from .mrthreshold import *
from .mrtransform import *
from .mtnormalise import *
from .peaks2amp import *
from .peaks2fixel import *
from .responsemean import *
from .sh2amp import *
from .sh2peaks import *
from .sh2power import *
from .sh2response import *
from .shbasis import *
from .shconv import *
from .tck2connectome import *
from .tck2fixel import *
from .tckconvert import *
from .tckdfc import *
from .tckedit import *
from .tckgen import *
from .tckglobal import *
from .tckinfo import *
from .tckmap import *
from .tckresample import *
from .tcksample import *
from .tcksift import *
from .tcksift2 import *
from .tckstats import *
from .tcktransform import *
from .tensor2metric import *
from .transformcalc import *
from .transformcompose import *
from .transformconvert import *
from .tsfdivide import *
from .tsfinfo import *
from .tsfmult import *
from .tsfsmooth import *
from .tsfthreshold import *
from .tsfvalidate import *
from .v_5tt2gmwmi import *
from .v_5tt2vis import *
from .v_5ttcheck import *
from .v_5ttedit import *
from .v_5ttgen import *
from .vectorstats import *
from .voxel2fixel import *
from .voxel2mesh import *
from .warp2metric import *
from .warpconvert import *
from .warpcorrect import *
from .warpinit import *
from .warpinvert import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_BIANCA_MASK_METADATA = Metadata(
    id="4c86228a8220f5a60129cb20c88b1a58d64d06a2.boutiques",
    name="make_bianca_mask",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MakeBiancaMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_bianca_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Output image"""


def make_bianca_mask(
    input_image: InputPathType,
    output_image: InputPathType,
    overlay_flag: bool = False,
    binary_mask_flag: bool = False,
    approx_skull_flag: bool = False,
    no_seg_output_flag: bool = False,
    fractional_intensity: float | None = None,
    vg_fractional_intensity: float | None = None,
    head_radius: float | None = None,
    center_of_gravity: str | None = None,
    thresholding_flag: bool = False,
    vtk_mesh: bool = False,
    robust_iters_flag: bool = False,
    residual_optic_cleanup_flag: bool = False,
    reduce_bias_flag: bool = False,
    slice_padding_flag: bool = False,
    whole_set_mask_flag: bool = False,
    additional_surfaces_flag: bool = False,
    additional_surfaces_t2: InputPathType | None = None,
    verbose_flag: bool = False,
    debug_flag: bool = False,
    runner: Runner | None = None,
) -> MakeBiancaMaskOutputs:
    """
    A script for generating BIANCA masks.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_image: Input image.
        output_image: Output image.
        overlay_flag: Generate brain surface outline overlaid onto original\
            image.
        binary_mask_flag: Generate binary brain mask.
        approx_skull_flag: Generate approximate skull image.
        no_seg_output_flag: Don't generate segmented brain image output.
        fractional_intensity: Fractional intensity threshold (0->1);\
            default=0.5; smaller values give larger brain outline estimates.
        vg_fractional_intensity: Vertical gradient in fractional intensity\
            threshold (-1->1); default=0; positive values give larger brain outline\
            at bottom, smaller at top.
        head_radius: Head radius (mm not voxels); initial surface sphere is set\
            to half of this.
        center_of_gravity: Centre-of-gravity (voxels not mm) of initial mesh\
            surface.
        thresholding_flag: Apply thresholding to segmented brain image and mask.
        vtk_mesh: Generates brain surface as mesh in .vtk format.
        robust_iters_flag: Robust brain center estimation (iterates BET several\
            times).
        residual_optic_cleanup_flag: Eye & optic nerve cleanup (can be useful\
            in SIENA - disables -o option).
        reduce_bias_flag: Bias field & neck cleanup (can be useful in SIENA).
        slice_padding_flag: Improve BET if FOV is very small in Z (by\
            temporarily padding end slices).
        whole_set_mask_flag: Apply to 4D FMRI data (uses -f 0.3 and dilates\
            brain mask slightly).
        additional_surfaces_flag: Run bet2 and then betsurf to get additional\
            skull and scalp surfaces (includes registrations).
        additional_surfaces_t2: As with -A, when also feeding in\
            non-brain-extracted T2 (includes registrations).
        verbose_flag: Verbose (switch on diagnostic messages).
        debug_flag: Debug (don't delete temporary intermediate images).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeBiancaMaskOutputs`).
    """
    if fractional_intensity is not None and not (0 <= fractional_intensity <= 1): 
        raise ValueError(f"'fractional_intensity' must be between 0 <= x <= 1 but was {fractional_intensity}")
    if vg_fractional_intensity is not None and not (-1 <= vg_fractional_intensity <= 1): 
        raise ValueError(f"'vg_fractional_intensity' must be between -1 <= x <= 1 but was {vg_fractional_intensity}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_BIANCA_MASK_METADATA)
    cargs = []
    cargs.append("make_bianca_mask")
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    if overlay_flag:
        cargs.append("-o")
    if binary_mask_flag:
        cargs.append("-m")
    if approx_skull_flag:
        cargs.append("-s")
    if no_seg_output_flag:
        cargs.append("-n")
    if fractional_intensity is not None:
        cargs.extend([
            "-f",
            str(fractional_intensity)
        ])
    if vg_fractional_intensity is not None:
        cargs.extend([
            "-g",
            str(vg_fractional_intensity)
        ])
    if head_radius is not None:
        cargs.extend([
            "-r",
            str(head_radius)
        ])
    if center_of_gravity is not None:
        cargs.extend([
            "-c",
            center_of_gravity
        ])
    if thresholding_flag:
        cargs.append("-t")
    if vtk_mesh:
        cargs.append("-e")
    if robust_iters_flag:
        cargs.append("-R")
    if residual_optic_cleanup_flag:
        cargs.append("-S")
    if reduce_bias_flag:
        cargs.append("-B")
    if slice_padding_flag:
        cargs.append("-Z")
    if whole_set_mask_flag:
        cargs.append("-F")
    if additional_surfaces_flag:
        cargs.append("-A")
    if additional_surfaces_t2 is not None:
        cargs.extend([
            "-A2",
            execution.input_file(additional_surfaces_t2)
        ])
    if verbose_flag:
        cargs.append("-v")
    if debug_flag:
        cargs.append("-d")
    ret = MakeBiancaMaskOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_BIANCA_MASK_METADATA",
    "MakeBiancaMaskOutputs",
    "make_bianca_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EDDY_SQUAD_METADATA = Metadata(
    id="6ecefb53fde2da8de13d6b0803475b0a4336061f.boutiques",
    name="eddy_squad",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class EddySquadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `eddy_squad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    qc_results: OutputPathType | None
    """QC results in JSON format"""


def eddy_squad(
    subject_list: str,
    grouping: str | None = None,
    group_db: InputPathType | None = None,
    update_: bool = False,
    output_dir: str | None = None,
    runner: Runner | None = None,
) -> EddySquadOutputs:
    """
    Study-wise QC for dMRI data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        subject_list: List of subject IDs for the QC.
        grouping: Specifies the grouping of studies.
        group_db: Path to the group database.
        update_: Option to update the QC results.
        output_dir: Output directory for the QC results.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `EddySquadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EDDY_SQUAD_METADATA)
    cargs = []
    cargs.append("eddy_squad")
    if grouping is not None:
        cargs.extend([
            "-g",
            grouping
        ])
    if group_db is not None:
        cargs.extend([
            "-gdb",
            execution.input_file(group_db)
        ])
    if update_:
        cargs.append("-u")
    if output_dir is not None:
        cargs.extend([
            "-o",
            output_dir
        ])
    cargs.append(subject_list)
    ret = EddySquadOutputs(
        root=execution.output_file("."),
        qc_results=execution.output_file(output_dir + "/qc_results.json") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EDDY_SQUAD_METADATA",
    "EddySquadOutputs",
    "eddy_squad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RENORMALIZE_SUBJECT_KEEP_EDITTING_METADATA = Metadata(
    id="d1c64f0c85672d74bb2cb15852e56662e6d58c32.boutiques",
    name="renormalize_subject_keep_editting",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RenormalizeSubjectKeepEdittingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `renormalize_subject_keep_editting(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Placeholder output file since tool details are not available."""


def renormalize_subject_keep_editting(
    runner: Runner | None = None,
) -> RenormalizeSubjectKeepEdittingOutputs:
    """
    A placeholder for the renormalize_subject_keep_editting tool, details not
    available.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RenormalizeSubjectKeepEdittingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RENORMALIZE_SUBJECT_KEEP_EDITTING_METADATA)
    cargs = []
    cargs.append("renormalize_subject_keep_editting")
    ret = RenormalizeSubjectKeepEdittingOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file("output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RENORMALIZE_SUBJECT_KEEP_EDITTING_METADATA",
    "RenormalizeSubjectKeepEdittingOutputs",
    "renormalize_subject_keep_editting",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CREATE_MORPH_METADATA = Metadata(
    id="27324e933d293e8e2b120cd3ed20c35684ee8e7e.boutiques",
    name="createMorph",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class CreateMorphOutputs(typing.NamedTuple):
    """
    Output object returned when calling `create_morph(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_transform_file: OutputPathType
    """The resulting output transform file in tm3d format."""


def create_morph(
    input_transforms: list[str],
    output_transform: InputPathType,
    template: InputPathType | None = None,
    subject: InputPathType | None = None,
    debug_coordinates: list[float] | None = None,
    runner: Runner | None = None,
) -> CreateMorphOutputs:
    """
    Tool to create morphological transformations using specified input transforms.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_transforms: Input transforms, must specify type (affine, volume,\
            morph, mesh, gcam) with filename.
        output_transform: Output transform file in tm3d format.
        template: Template volume for geometry. Required if a gcam is present.
        subject: Subject volume for geometry.
        debug_coordinates: Coordinates for debugging purposes. Requires three\
            integer values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CreateMorphOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CREATE_MORPH_METADATA)
    cargs = []
    cargs.append("createMorph")
    cargs.extend([
        "--in",
        *input_transforms
    ])
    cargs.extend([
        "--out",
        execution.input_file(output_transform)
    ])
    if template is not None:
        cargs.extend([
            "--template",
            execution.input_file(template)
        ])
    if subject is not None:
        cargs.extend([
            "--subject",
            execution.input_file(subject)
        ])
    if debug_coordinates is not None:
        cargs.extend([
            "--dbg",
            *map(str, debug_coordinates)
        ])
    ret = CreateMorphOutputs(
        root=execution.output_file("."),
        output_transform_file=execution.output_file(pathlib.Path(output_transform).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CREATE_MORPH_METADATA",
    "CreateMorphOutputs",
    "create_morph",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_3D_PHOTO_RECON_METADATA = Metadata(
    id="65e6002ea15ce2bd0acb1ae3f6efe0b8f986e100.boutiques",
    name="mri_3d_photo_recon",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Mri3dPhotoReconOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_3d_photo_recon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reconstructed_volume: OutputPathType
    """Reconstructed photo volume output file"""
    reference_data: OutputPathType
    """Output reference data"""


def mri_3d_photo_recon(
    input_photo_dir: list[InputPathType],
    input_segmentation_dir: list[InputPathType],
    slice_thickness: float,
    photo_resolution: float,
    output_directory: str,
    ref_mask: InputPathType | None = None,
    ref_surface: InputPathType | None = None,
    ref_soft_mask: InputPathType | None = None,
    mesh_reorient_with_indices: str | None = None,
    photos_posterior_side: bool = False,
    order_posterior_to_anterior: bool = False,
    allow_z_stretch: bool = False,
    rigid_only_for_photos: bool = False,
    gpu_index: float | None = None,
    runner: Runner | None = None,
) -> Mri3dPhotoReconOutputs:
    """
    Code for 3D photo reconstruction (Tregidgo, et al., MICCAI 2020).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_photo_dir: Directory with input photos (required).
        input_segmentation_dir: Directory with input slab masks / segmentations\
            (required).
        slice_thickness: Slice thickness in mm.
        photo_resolution: Resolution of the photos in mm.
        output_directory: Output directory with reconstructed photo volume and\
            reference.
        ref_mask: Reference binary mask.
        ref_surface: Reference surface file.
        ref_soft_mask: Reference soft mask.
        mesh_reorient_with_indices: Vertex indices of frontal pole, occipital\
            pole, and top of central sulcus, separated with commas, for mesh\
            alignment.
        photos_posterior_side: Use when photos are taken of posterior side of\
            slabs (default is anterior side).
        order_posterior_to_anterior: Use when photos are ordered from posterior\
            to anterior (default is anterior to posterior).
        allow_z_stretch: Use to adjust the slice thickness to best match the\
            reference. You should probably *never* use this with soft references\
            (ref_soft_mask).
        rigid_only_for_photos: Switch on if you want photos to deform only\
            rigidly (not affine).
        gpu_index: Index of GPU to use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Mri3dPhotoReconOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_3D_PHOTO_RECON_METADATA)
    cargs = []
    cargs.append("mri_3d_photo_recon")
    cargs.extend([
        "--input_photo_dir",
        *[execution.input_file(f) for f in input_photo_dir]
    ])
    cargs.extend([
        "--input_segmentation_dir",
        *[execution.input_file(f) for f in input_segmentation_dir]
    ])
    cargs.extend([
        "--slice_thickness",
        str(slice_thickness)
    ])
    cargs.extend([
        "--photo_resolution",
        str(photo_resolution)
    ])
    cargs.extend([
        "--output_directory",
        output_directory
    ])
    if ref_mask is not None:
        cargs.extend([
            "--ref_mask",
            execution.input_file(ref_mask)
        ])
    if ref_surface is not None:
        cargs.extend([
            "--ref_surface",
            execution.input_file(ref_surface)
        ])
    if ref_soft_mask is not None:
        cargs.extend([
            "--ref_soft_mask",
            execution.input_file(ref_soft_mask)
        ])
    if mesh_reorient_with_indices is not None:
        cargs.extend([
            "--mesh_reorient_with_indices",
            mesh_reorient_with_indices
        ])
    if photos_posterior_side:
        cargs.append("--photos_of_posterior_side")
    if order_posterior_to_anterior:
        cargs.append("--order_posterior_to_anterior")
    if allow_z_stretch:
        cargs.append("--allow_z_stretch")
    if rigid_only_for_photos:
        cargs.append("--rigid_only_for_photos")
    if gpu_index is not None:
        cargs.extend([
            "--gpu",
            str(gpu_index)
        ])
    ret = Mri3dPhotoReconOutputs(
        root=execution.output_file("."),
        reconstructed_volume=execution.output_file(output_directory + "/reconstructed_volume.nii.gz"),
        reference_data=execution.output_file(output_directory + "/reference_data.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_3D_PHOTO_RECON_METADATA",
    "Mri3dPhotoReconOutputs",
    "mri_3d_photo_recon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_EXTRACT_PATCHES_METADATA = Metadata(
    id="4b1b272c0e5d898fdbf11dee43aa5f15d5fc44a4.boutiques",
    name="mris_extract_patches",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisExtractPatchesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_extract_patches(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_extract_patches(
    subject: str,
    output_dir: str,
    runner: Runner | None = None,
) -> MrisExtractPatchesOutputs:
    """
    A tool for extracting patches from brain surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject from which patches are to be extracted.
        output_dir: Output directory where patches will be saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisExtractPatchesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_EXTRACT_PATCHES_METADATA)
    cargs = []
    cargs.append("mris_extract_patches")
    cargs.append(subject)
    cargs.append(output_dir)
    ret = MrisExtractPatchesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_EXTRACT_PATCHES_METADATA",
    "MrisExtractPatchesOutputs",
    "mris_extract_patches",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MERGELABELS_METADATA = Metadata(
    id="6f1119002868794fb350ad4069f13562cf64aaa1.boutiques",
    name="mri_mergelabels",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMergelabelsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mergelabels(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    merged_label_file: OutputPathType
    """Merged label output file"""


def mri_mergelabels(
    input_labels: list[InputPathType],
    output_label: str,
    input_directory: str | None = None,
    runner: Runner | None = None,
) -> MriMergelabelsOutputs:
    """
    A tool to merge two or more label files by concatenating them together.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_labels: Input label files to be merged.
        output_label: Output file for the merged label.
        input_directory: Directory containing label files to be merged.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMergelabelsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MERGELABELS_METADATA)
    cargs = []
    cargs.append("mri_mergelabels")
    cargs.extend([
        "-i",
        *[execution.input_file(f) for f in input_labels]
    ])
    cargs.extend([
        "-o",
        output_label
    ])
    if input_directory is not None:
        cargs.extend([
            "-d",
            input_directory
        ])
    ret = MriMergelabelsOutputs(
        root=execution.output_file("."),
        merged_label_file=execution.output_file(output_label),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MERGELABELS_METADATA",
    "MriMergelabelsOutputs",
    "mri_mergelabels",
]
